@@ -17,12 +17,14 @@ insDoc(aux1, gLnk("R", "ACBN0Screening", "vars/Hamiltonian.html#ACBN0Screening")
 insDoc(aux1, gLnk("R", "AccelBenchmark", "vars/Execution.html#AccelBenchmark"))
 insDoc(aux1, gLnk("R", "AccelDevice", "vars/Execution.html#AccelDevice"))
 insDoc(aux1, gLnk("R", "AccelPlatform", "vars/Execution.html#AccelPlatform"))
+insDoc(aux1, gLnk("R", "AdaptivelyCompressedExchange", "vars/Hamiltonian.html#AdaptivelyCompressedExchange"))
+insDoc(aux1, gLnk("R", "AllowCPUonly", "vars/Execution.html#AllowCPUonly"))
 insDoc(aux1, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux1, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
 insDoc(aux1, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
 insDoc(aux1, gLnk("R", "AOLoewdin", "vars/Atomic_Orbitals.html#AOLoewdin"))
 insDoc(aux1, gLnk("R", "AONormalize", "vars/Atomic_Orbitals.html#AONormalize"))
-insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Atomic_Orbitals.html#AOSubmeshForPeriodic"))
+insDoc(aux1, gLnk("R", "AOSubmesh", "vars/Atomic_Orbitals.html#AOSubmesh"))
 insDoc(aux1, gLnk("R", "AOThreshold", "vars/Atomic_Orbitals.html#AOThreshold"))
 insDoc(aux1, gLnk("R", "AOTruncation", "vars/Atomic_Orbitals.html#AOTruncation"))
 insDoc(aux1, gLnk("R", "ArnoldiOrthogonalization", "vars/Time-Dependent.html#ArnoldiOrthogonalization"))
@@ -46,7 +48,6 @@ insDoc(aux1, gLnk("R", "BoxShape", "vars/Mesh.html#BoxShape"))
 insDoc(aux1, gLnk("R", "BoxShapeImage", "vars/Mesh.html#BoxShapeImage"))
 insDoc(aux1, gLnk("R", "BoxShapeUsDef", "vars/Mesh.html#BoxShapeUsDef"))
 aux1 = insFld(aux0, gFld("C", "javascript:parent.op()"))
-insDoc(aux1, gLnk("R", "CalcEigenvalues", "vars/SCF.html#CalcEigenvalues"))
 insDoc(aux1, gLnk("R", "CalcInfrared", "vars/Linear_Response.html#CalcInfrared"))
 insDoc(aux1, gLnk("R", "CalcNormalModeWfs", "vars/Linear_Response.html#CalcNormalModeWfs"))
 insDoc(aux1, gLnk("R", "CalculateSelfInducedMagneticField", "vars/Hamiltonian.html#CalculateSelfInducedMagneticField"))
@@ -55,10 +56,12 @@ insDoc(aux1, gLnk("R", "CasidaCalcForces", "vars/Linear_Response.html#CasidaCalc
 insDoc(aux1, gLnk("R", "CasidaCalcForcesKernel", "vars/Linear_Response.html#CasidaCalcForcesKernel"))
 insDoc(aux1, gLnk("R", "CasidaCalcForcesSCF", "vars/Linear_Response.html#CasidaCalcForcesSCF"))
 insDoc(aux1, gLnk("R", "CasidaCalcTriplet", "vars/Linear_Response.html#CasidaCalcTriplet"))
+insDoc(aux1, gLnk("R", "CasidaDistributedMatrix", "vars/Linear_Response.html#CasidaDistributedMatrix"))
 insDoc(aux1, gLnk("R", "CasidaHermitianConjugate", "vars/Linear_Response.html#CasidaHermitianConjugate"))
 insDoc(aux1, gLnk("R", "CasidaKohnShamStates", "vars/Linear_Response.html#CasidaKohnShamStates"))
 insDoc(aux1, gLnk("R", "CasidaKSEnergyWindow", "vars/Linear_Response.html#CasidaKSEnergyWindow"))
 insDoc(aux1, gLnk("R", "CasidaMomentumTransfer", "vars/Linear_Response.html#CasidaMomentumTransfer"))
+insDoc(aux1, gLnk("R", "CasidaParallelEigensolver", "vars/Linear_Response.html#CasidaParallelEigensolver"))
 insDoc(aux1, gLnk("R", "CasidaPrintExcitations", "vars/Linear_Response.html#CasidaPrintExcitations"))
 insDoc(aux1, gLnk("R", "CasidaQuadratureOrder", "vars/Linear_Response.html#CasidaQuadratureOrder"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumBroadening", "vars/Utilities.html#CasidaSpectrumBroadening"))
@@ -69,14 +72,12 @@ insDoc(aux1, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#Casi
 insDoc(aux1, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux1, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
 insDoc(aux1, gLnk("R", "CasidaWeightThreshold", "vars/Linear_Response.html#CasidaWeightThreshold"))
+insDoc(aux1, gLnk("R", "CasidaWriteDistributedMatrix", "vars/Linear_Response.html#CasidaWriteDistributedMatrix"))
 insDoc(aux1, gLnk("R", "CGAdditionalTerms", "vars/SCF.html#CGAdditionalTerms"))
 insDoc(aux1, gLnk("R", "CGDirection", "vars/SCF.html#CGDirection"))
 insDoc(aux1, gLnk("R", "CGEnergyChangeThreshold", "vars/SCF.html#CGEnergyChangeThreshold"))
 insDoc(aux1, gLnk("R", "CGOrthogonalizeAll", "vars/SCF.html#CGOrthogonalizeAll"))
-insDoc(aux1, gLnk("R", "ClassicalParticleCharge", "vars/ClassicalParticles.html#ClassicalParticleCharge"))
-insDoc(aux1, gLnk("R", "ClassicalParticleInitialPosition", "vars/ClassicalParticles.html#ClassicalParticleInitialPosition"))
-insDoc(aux1, gLnk("R", "ClassicalParticleInitialVelocity", "vars/ClassicalParticles.html#ClassicalParticleInitialVelocity"))
-insDoc(aux1, gLnk("R", "ClassicalParticleMass", "vars/ClassicalParticles.html#ClassicalParticleMass"))
+insDoc(aux1, gLnk("R", "CheckPointsMediumFromFile", "vars/Maxwell.html#CheckPointsMediumFromFile"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "ConductivityFromForces", "vars/Utilities.html#ConductivityFromForces"))
 insDoc(aux1, gLnk("R", "ConductivitySpectrumTimeStepFactor", "vars/Utilities.html#ConductivitySpectrumTimeStepFactor"))
@@ -102,7 +103,6 @@ insDoc(aux1, gLnk("R", "ConvertStep", "vars/Utilities.html#ConvertStep"))
 insDoc(aux1, gLnk("R", "ConvertSubtract", "vars/Utilities.html#ConvertSubtract"))
 insDoc(aux1, gLnk("R", "ConvertSubtractFilename", "vars/Utilities.html#ConvertSubtractFilename"))
 insDoc(aux1, gLnk("R", "ConvertSubtractFolder", "vars/Utilities.html#ConvertSubtractFolder"))
-insDoc(aux1, gLnk("R", "ConvForce", "vars/SCF.html#ConvForce"))
 insDoc(aux1, gLnk("R", "ConvRelDens", "vars/SCF.html#ConvRelDens"))
 insDoc(aux1, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
 insDoc(aux1, gLnk("R", "Coordinates", "vars/System.html#Coordinates"))
@@ -140,8 +140,6 @@ insDoc(aux1, gLnk("R", "DOSEnergyMin", "vars/Output.html#DOSEnergyMin"))
 insDoc(aux1, gLnk("R", "DOSEnergyPoints", "vars/Output.html#DOSEnergyPoints"))
 insDoc(aux1, gLnk("R", "DOSGamma", "vars/Output.html#DOSGamma"))
 insDoc(aux1, gLnk("R", "DoubleFFTParameter", "vars/Mesh.html#DoubleFFTParameter"))
-insDoc(aux1, gLnk("R", "DoubleGrid", "vars/Mesh.html#DoubleGrid"))
-insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
 insDoc(aux1, gLnk("R", "DressedOrbitals", "vars/Hamiltonian.html#DressedOrbitals"))
 aux1 = insFld(aux0, gFld("E", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
@@ -169,6 +167,7 @@ insDoc(aux1, gLnk("R", "EMStaticElectricField", "vars/Linear_Response.html#EMSta
 insDoc(aux1, gLnk("R", "EMVerbose", "vars/Linear_Response.html#EMVerbose"))
 insDoc(aux1, gLnk("R", "EMWavefunctionsFromScratch", "vars/Linear_Response.html#EMWavefunctionsFromScratch"))
 insDoc(aux1, gLnk("R", "EMWriteRestartDensities", "vars/Linear_Response.html#EMWriteRestartDensities"))
+insDoc(aux1, gLnk("R", "EnablePhotons", "vars/Hamiltonian.html#EnablePhotons"))
 insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
 insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
@@ -180,7 +179,6 @@ insDoc(aux1, gLnk("R", "FFTLibrary", "vars/Mesh.html#FFTLibrary"))
 insDoc(aux1, gLnk("R", "FFTOptimize", "vars/Mesh.html#FFTOptimize"))
 insDoc(aux1, gLnk("R", "FFTPreparePlan", "vars/Mesh.html#FFTPreparePlan"))
 insDoc(aux1, gLnk("R", "FilterPotentials", "vars/Hamiltonian.html#FilterPotentials"))
-insDoc(aux1, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
 insDoc(aux1, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
 insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
@@ -209,10 +207,13 @@ insDoc(aux1, gLnk("R", "HFSingularity", "vars/Hamiltonian.html#HFSingularity"))
 insDoc(aux1, gLnk("R", "HFSingularityNk", "vars/Hamiltonian.html#HFSingularityNk"))
 insDoc(aux1, gLnk("R", "HFSingularityNsteps", "vars/Hamiltonian.html#HFSingularityNsteps"))
 aux1 = insFld(aux0, gFld("I", "javascript:parent.op()"))
-insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
+insDoc(aux1, gLnk("R", "InitialIonicTemperature", "vars/DFTBPlusInterface.html#InitialIonicTemperature"))
 insDoc(aux1, gLnk("R", "InitialSpins", "vars/States.html#InitialSpins"))
 insDoc(aux1, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
 insDoc(aux1, gLnk("R", "Interaction1DScreening", "vars/Hamiltonian.html#Interaction1DScreening"))
+insDoc(aux1, gLnk("R", "Interactions", "vars/System.html#Interactions"))
+insDoc(aux1, gLnk("R", "InteractionTiming", "vars/Time-Dependent.html#InteractionTiming"))
+insDoc(aux1, gLnk("R", "InterpolationTestOrder", "vars/Calculation_Modes.html#InterpolationTestOrder"))
 insDoc(aux1, gLnk("R", "InvertKSConvAbsDens", "vars/Calculation_Modes.html#InvertKSConvAbsDens"))
 insDoc(aux1, gLnk("R", "InvertKSGodbyMu", "vars/Calculation_Modes.html#InvertKSGodbyMu"))
 insDoc(aux1, gLnk("R", "InvertKSGodbyPower", "vars/Calculation_Modes.html#InvertKSGodbyPower"))
@@ -254,7 +255,6 @@ insDoc(aux1, gLnk("R", "LCAOScaleFactor", "vars/SCF.html#LCAOScaleFactor"))
 insDoc(aux1, gLnk("R", "LCAOStart", "vars/SCF.html#LCAOStart"))
 insDoc(aux1, gLnk("R", "LDBaderThreshold", "vars/Utilities.html#LDBaderThreshold"))
 insDoc(aux1, gLnk("R", "LDEnd", "vars/Utilities.html#LDEnd"))
-insDoc(aux1, gLnk("R", "LDExtraWrite", "vars/Utilities.html#LDExtraWrite"))
 insDoc(aux1, gLnk("R", "LDFilename", "vars/Utilities.html#LDFilename"))
 insDoc(aux1, gLnk("R", "LDFolder", "vars/Utilities.html#LDFolder"))
 insDoc(aux1, gLnk("R", "LDIonicDipole", "vars/Utilities.html#LDIonicDipole"))
@@ -273,6 +273,13 @@ insDoc(aux1, gLnk("R", "LDUseAtomicRadii", "vars/Utilities.html#LDUseAtomicRadii
 insDoc(aux1, gLnk("R", "libvdwxcDebug", "vars/Hamiltonian.html#libvdwxcDebug"))
 insDoc(aux1, gLnk("R", "libvdwxcMode", "vars/Hamiltonian.html#libvdwxcMode"))
 insDoc(aux1, gLnk("R", "libvdwxcVDWFactor", "vars/Hamiltonian.html#libvdwxcVDWFactor"))
+insDoc(aux1, gLnk("R", "LinearMediumBoxFile", "vars/Maxwell.html#LinearMediumBoxFile"))
+insDoc(aux1, gLnk("R", "LinearMediumBoxShape", "vars/Maxwell.html#LinearMediumBoxShape"))
+insDoc(aux1, gLnk("R", "LinearMediumBoxSize", "vars/Maxwell.html#LinearMediumBoxSize"))
+insDoc(aux1, gLnk("R", "LinearMediumEdgeProfile", "vars/Maxwell.html#LinearMediumEdgeProfile"))
+insDoc(aux1, gLnk("R", "LinearMediumOutput", "vars/Output.html#LinearMediumOutput"))
+insDoc(aux1, gLnk("R", "LinearMediumOutputDir", "vars/Output.html#LinearMediumOutputDir"))
+insDoc(aux1, gLnk("R", "LinearMediumProperties", "vars/Maxwell.html#LinearMediumProperties"))
 insDoc(aux1, gLnk("R", "LinearSolver", "vars/Linear_Response.html#LinearSolver"))
 insDoc(aux1, gLnk("R", "LinearSolverMaxIter", "vars/Linear_Response.html#LinearSolverMaxIter"))
 insDoc(aux1, gLnk("R", "LocalDomains", "vars/Utilities.html#LocalDomains"))
@@ -287,9 +294,12 @@ insDoc(aux1, gLnk("R", "LRTolIterWindow", "vars/Linear_Response.html#LRTolIterWi
 insDoc(aux1, gLnk("R", "LRTolScheme", "vars/Linear_Response.html#LRTolScheme"))
 insDoc(aux1, gLnk("R", "Lsize", "vars/Mesh.html#Lsize"))
 aux1 = insFld(aux0, gFld("M", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "MagneticConstrain", "vars/Hamiltonian.html#MagneticConstrain"))
+insDoc(aux1, gLnk("R", "MagneticConstrainStrength", "vars/Hamiltonian.html#MagneticConstrainStrength"))
 insDoc(aux1, gLnk("R", "MagneticGaugeCorrection", "vars/Linear_Response.html#MagneticGaugeCorrection"))
 insDoc(aux1, gLnk("R", "MainAxis", "vars/Utilities.html#MainAxis"))
 insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
+insDoc(aux1, gLnk("R", "MaxAngularMomentum", "vars/DFTBPlusInterface.html#MaxAngularMomentum"))
 insDoc(aux1, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
 insDoc(aux1, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
 insDoc(aux1, gLnk("R", "MaxwellABPMLPower", "vars/Time-Dependent.html#MaxwellABPMLPower"))
@@ -297,11 +307,10 @@ insDoc(aux1, gLnk("R", "MaxwellABPMLReflectionError", "vars/Time-Dependent.html#
 insDoc(aux1, gLnk("R", "MaxwellAbsorbingBoundaries", "vars/Time-Dependent.html#MaxwellAbsorbingBoundaries"))
 insDoc(aux1, gLnk("R", "MaxwellABWidth", "vars/Time-Dependent.html#MaxwellABWidth"))
 insDoc(aux1, gLnk("R", "MaxwellBoundaryConditions", "vars/Time-Dependent.html#MaxwellBoundaryConditions"))
-insDoc(aux1, gLnk("R", "MaxwellFieldsCoordinate", "vars/System.html#MaxwellFieldsCoordinate"))
+insDoc(aux1, gLnk("R", "MaxwellFieldsCoordinate", "vars/Maxwell.html#MaxwellFieldsCoordinate"))
 insDoc(aux1, gLnk("R", "MaxwellFunctions", "vars/Time-Dependent.html#MaxwellFunctions"))
 insDoc(aux1, gLnk("R", "MaxwellHamiltonianOperator", "vars/Hamiltonian.html#MaxwellHamiltonianOperator"))
 insDoc(aux1, gLnk("R", "MaxwellIncidentWaves", "vars/MaxwellStates.html#MaxwellIncidentWaves"))
-insDoc(aux1, gLnk("R", "MaxwellMediumBox", "vars/Time-Dependent.html#MaxwellMediumBox"))
 insDoc(aux1, gLnk("R", "MaxwellMediumCalculation", "vars/Hamiltonian.html#MaxwellMediumCalculation"))
 insDoc(aux1, gLnk("R", "MaxwellOutput", "vars/Output.html#MaxwellOutput"))
 insDoc(aux1, gLnk("R", "MaxwellOutputInterval", "vars/Output.html#MaxwellOutputInterval"))
@@ -309,27 +318,38 @@ insDoc(aux1, gLnk("R", "MaxwellOutputIterDir", "vars/Output.html#MaxwellOutputIt
 insDoc(aux1, gLnk("R", "MaxwellPlaneWavesInBox", "vars/States.html#MaxwellPlaneWavesInBox"))
 insDoc(aux1, gLnk("R", "MaxwellRestartWriteInterval", "vars/Execution.html#MaxwellRestartWriteInterval"))
 insDoc(aux1, gLnk("R", "MaxwellTDETRSApprox", "vars/Time-Dependent.html#MaxwellTDETRSApprox"))
-insDoc(aux1, gLnk("R", "MaxwellTDIntervalSteps", "vars/Time-Dependent.html#MaxwellTDIntervalSteps"))
 insDoc(aux1, gLnk("R", "MaxwellTDOperatorMethod", "vars/Time-Dependent.html#MaxwellTDOperatorMethod"))
 insDoc(aux1, gLnk("R", "MaxwellTDOutput", "vars/Time-Dependent.html#MaxwellTDOutput"))
 insDoc(aux1, gLnk("R", "MaxwellTDSCFThreshold", "vars/Time-Dependent.html#MaxwellTDSCFThreshold"))
+insDoc(aux1, gLnk("R", "MediumCurrentCoordinates", "vars/Maxwell.html#MediumCurrentCoordinates"))
+insDoc(aux1, gLnk("R", "MediumDispersionType", "vars/Maxwell.html#MediumDispersionType"))
 insDoc(aux1, gLnk("R", "MediumElectricSigma", "vars/Time-Dependent.html#MediumElectricSigma"))
 insDoc(aux1, gLnk("R", "MediumEpsilonFactor", "vars/Time-Dependent.html#MediumEpsilonFactor"))
 insDoc(aux1, gLnk("R", "MediumMagneticSigma", "vars/Time-Dependent.html#MediumMagneticSigma"))
 insDoc(aux1, gLnk("R", "MediumMuFactor", "vars/Time-Dependent.html#MediumMuFactor"))
+insDoc(aux1, gLnk("R", "MediumPoleDamping", "vars/Maxwell.html#MediumPoleDamping"))
+insDoc(aux1, gLnk("R", "MediumPoleEnergy", "vars/Maxwell.html#MediumPoleEnergy"))
+insDoc(aux1, gLnk("R", "MediumPoleStrength", "vars/Maxwell.html#MediumPoleStrength"))
 insDoc(aux1, gLnk("R", "MediumWidth", "vars/Time-Dependent.html#MediumWidth"))
 insDoc(aux1, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
+insDoc(aux1, gLnk("R", "MeshBlockDirection", "vars/Execution.html#MeshBlockDirection"))
 insDoc(aux1, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
+insDoc(aux1, gLnk("R", "MeshIndexType", "vars/Mesh.html#MeshIndexType"))
+insDoc(aux1, gLnk("R", "MeshLocalBlockDirection", "vars/Execution.html#MeshLocalBlockDirection"))
+insDoc(aux1, gLnk("R", "MeshLocalBlockSize", "vars/Execution.html#MeshLocalBlockSize"))
+insDoc(aux1, gLnk("R", "MeshLocalOrder", "vars/Execution.html#MeshLocalOrder"))
 insDoc(aux1, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
 insDoc(aux1, gLnk("R", "MeshPartition", "vars/Execution.html#MeshPartition"))
 insDoc(aux1, gLnk("R", "MeshPartitionPackage", "vars/Execution.html#MeshPartitionPackage"))
 insDoc(aux1, gLnk("R", "MeshPartitionStencil", "vars/Execution.html#MeshPartitionStencil"))
 insDoc(aux1, gLnk("R", "MeshPartitionVirtualSize", "vars/Execution.html#MeshPartitionVirtualSize"))
 insDoc(aux1, gLnk("R", "MeshUseTopology", "vars/Execution.html#MeshUseTopology"))
+insDoc(aux1, gLnk("R", "MillerIndicesBasis", "vars/Time-Dependent.html#MillerIndicesBasis"))
 insDoc(aux1, gLnk("R", "MixField", "vars/SCF.html#MixField"))
 insDoc(aux1, gLnk("R", "Mixing", "vars/SCF.html#Mixing"))
 insDoc(aux1, gLnk("R", "MixingPreconditioner", "vars/SCF.html#MixingPreconditioner"))
 insDoc(aux1, gLnk("R", "MixingResidual", "vars/SCF.html#MixingResidual"))
+insDoc(aux1, gLnk("R", "MixingRestart", "vars/SCF.html#MixingRestart"))
 insDoc(aux1, gLnk("R", "MixingScheme", "vars/SCF.html#MixingScheme"))
 insDoc(aux1, gLnk("R", "MixInterval", "vars/SCF.html#MixInterval"))
 insDoc(aux1, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
@@ -338,8 +358,6 @@ insDoc(aux1, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
 insDoc(aux1, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
 insDoc(aux1, gLnk("R", "MultigridDerivativesOrder", "vars/Mesh.html#MultigridDerivativesOrder"))
 insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
-insDoc(aux1, gLnk("R", "MultiResolutionArea", "vars/Mesh.html#MultiResolutionArea"))
-insDoc(aux1, gLnk("R", "MultiResolutionInterpolationOrder", "vars/Mesh.html#MultiResolutionInterpolationOrder"))
 aux1 = insFld(aux0, gFld("N", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "NDimModelmb", "vars/States.html#NDimModelmb"))
 insDoc(aux1, gLnk("R", "NFFTCutoff", "vars/Mesh.html#NFFTCutoff"))
@@ -403,12 +421,10 @@ insDoc(aux1, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateCompl
 insDoc(aux1, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
 insDoc(aux1, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
-insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
 insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
-insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputMEEnd", "vars/Output.html#OutputMEEnd"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
@@ -423,6 +439,9 @@ insDoc(aux1, gLnk("R", "ParDomains", "vars/Execution.html#ParDomains"))
 insDoc(aux1, gLnk("R", "ParKPoints", "vars/Execution.html#ParKPoints"))
 insDoc(aux1, gLnk("R", "ParOther", "vars/Execution.html#ParOther"))
 insDoc(aux1, gLnk("R", "ParStates", "vars/Execution.html#ParStates"))
+insDoc(aux1, gLnk("R", "ParticleCharge", "vars/ClassicalParticles.html#ParticleCharge"))
+insDoc(aux1, gLnk("R", "ParticleInitialPosition", "vars/ClassicalParticles.html#ParticleInitialPosition"))
+insDoc(aux1, gLnk("R", "ParticleInitialVelocity", "vars/ClassicalParticles.html#ParticleInitialVelocity"))
 insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
 insDoc(aux1, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
 insDoc(aux1, gLnk("R", "PCMCalcMethod", "vars/Hamiltonian.html#PCMCalcMethod"))
@@ -456,23 +475,29 @@ insDoc(aux1, gLnk("R", "PDBGOConstrains", "vars/Calculation_Modes.html#PDBGOCons
 insDoc(aux1, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
 insDoc(aux1, gLnk("R", "PeriodicBoundaryMask", "vars/Mesh.html#PeriodicBoundaryMask"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
+insDoc(aux1, gLnk("R", "PES_Flux_AnisotropyCorrection", "vars/Time-Dependent.html#PES_Flux_AnisotropyCorrection"))
 insDoc(aux1, gLnk("R", "PES_Flux_ARPES_grid", "vars/Time-Dependent.html#PES_Flux_ARPES_grid"))
-insDoc(aux1, gLnk("R", "PES_Flux_AvoidAB", "vars/Time-Dependent.html#PES_Flux_AvoidAB"))
-insDoc(aux1, gLnk("R", "PES_Flux_BZones", "vars/Time-Dependent.html#PES_Flux_BZones"))
 insDoc(aux1, gLnk("R", "PES_Flux_DeltaK", "vars/Time-Dependent.html#PES_Flux_DeltaK"))
 insDoc(aux1, gLnk("R", "PES_Flux_EnergyGrid", "vars/Time-Dependent.html#PES_Flux_EnergyGrid"))
-insDoc(aux1, gLnk("R", "PES_Flux_Gpoint_Upsample", "vars/Time-Dependent.html#PES_Flux_Gpoint_Upsample"))
+insDoc(aux1, gLnk("R", "PES_Flux_Face_Dens", "vars/Time-Dependent.html#PES_Flux_Face_Dens"))
+insDoc(aux1, gLnk("R", "PES_Flux_GridTransformMatrix", "vars/Time-Dependent.html#PES_Flux_GridTransformMatrix"))
 insDoc(aux1, gLnk("R", "PES_Flux_Kmax", "vars/Time-Dependent.html#PES_Flux_Kmax"))
+insDoc(aux1, gLnk("R", "PES_Flux_Kmin", "vars/Time-Dependent.html#PES_Flux_Kmin"))
 insDoc(aux1, gLnk("R", "PES_Flux_Lmax", "vars/Time-Dependent.html#PES_Flux_Lmax"))
 insDoc(aux1, gLnk("R", "PES_Flux_Lsize", "vars/Time-Dependent.html#PES_Flux_Lsize"))
+insDoc(aux1, gLnk("R", "PES_Flux_Momenutum_Grid", "vars/Time-Dependent.html#PES_Flux_Momenutum_Grid"))
 insDoc(aux1, gLnk("R", "PES_Flux_Offset", "vars/Time-Dependent.html#PES_Flux_Offset"))
+insDoc(aux1, gLnk("R", "PES_Flux_Parallelization", "vars/Time-Dependent.html#PES_Flux_Parallelization"))
+insDoc(aux1, gLnk("R", "PES_Flux_PhiK", "vars/Time-Dependent.html#PES_Flux_PhiK"))
 insDoc(aux1, gLnk("R", "PES_Flux_Radius", "vars/Time-Dependent.html#PES_Flux_Radius"))
+insDoc(aux1, gLnk("R", "PES_Flux_RuntimeOutput", "vars/Time-Dependent.html#PES_Flux_RuntimeOutput"))
 insDoc(aux1, gLnk("R", "PES_Flux_Shape", "vars/Time-Dependent.html#PES_Flux_Shape"))
 insDoc(aux1, gLnk("R", "PES_Flux_StepsPhiK", "vars/Time-Dependent.html#PES_Flux_StepsPhiK"))
 insDoc(aux1, gLnk("R", "PES_Flux_StepsPhiR", "vars/Time-Dependent.html#PES_Flux_StepsPhiR"))
 insDoc(aux1, gLnk("R", "PES_Flux_StepsThetaK", "vars/Time-Dependent.html#PES_Flux_StepsThetaK"))
 insDoc(aux1, gLnk("R", "PES_Flux_StepsThetaR", "vars/Time-Dependent.html#PES_Flux_StepsThetaR"))
-insDoc(aux1, gLnk("R", "PES_Flux_UseMemory", "vars/Time-Dependent.html#PES_Flux_UseMemory"))
+insDoc(aux1, gLnk("R", "PES_Flux_ThetaK", "vars/Time-Dependent.html#PES_Flux_ThetaK"))
+insDoc(aux1, gLnk("R", "PES_Flux_UseSymmetries", "vars/Time-Dependent.html#PES_Flux_UseSymmetries"))
 insDoc(aux1, gLnk("R", "PES_spm_DeltaOmega", "vars/Time-Dependent.html#PES_spm_DeltaOmega"))
 insDoc(aux1, gLnk("R", "PES_spm_OmegaMax", "vars/Time-Dependent.html#PES_spm_OmegaMax"))
 insDoc(aux1, gLnk("R", "PES_spm_points", "vars/Time-Dependent.html#PES_spm_points"))
@@ -494,8 +519,11 @@ insDoc(aux1, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStar
 insDoc(aux1, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
 insDoc(aux1, gLnk("R", "PhotoelectronSpectrumOutput", "vars/Utilities.html#PhotoelectronSpectrumOutput"))
 insDoc(aux1, gLnk("R", "PhotoelectronSpectrumResolveStates", "vars/Utilities.html#PhotoelectronSpectrumResolveStates"))
+insDoc(aux1, gLnk("R", "PhotonEta", "vars/Linear_Response.html#PhotonEta"))
 insDoc(aux1, gLnk("R", "PhotonModes", "vars/Hamiltonian.html#PhotonModes"))
-insDoc(aux1, gLnk("R", "Photons", "vars/Hamiltonian.html#Photons"))
+insDoc(aux1, gLnk("R", "PhotonmodesFilename", "vars/Linear_Response.html#PhotonmodesFilename"))
+insDoc(aux1, gLnk("R", "PlaneWavesOnOneSide", "vars/Maxwell.html#PlaneWavesOnOneSide"))
+insDoc(aux1, gLnk("R", "PlaneWavesSide", "vars/Maxwell.html#PlaneWavesSide"))
 insDoc(aux1, gLnk("R", "PNFFTCutoff", "vars/Mesh.html#PNFFTCutoff"))
 insDoc(aux1, gLnk("R", "PNFFTOversampling", "vars/Mesh.html#PNFFTOversampling"))
 insDoc(aux1, gLnk("R", "Poisson1DSoftCoulombParam", "vars/Hamiltonian.html#Poisson1DSoftCoulombParam"))
@@ -514,6 +542,7 @@ insDoc(aux1, gLnk("R", "PoissonSolverMGRestrictionMethod", "vars/Hamiltonian.htm
 insDoc(aux1, gLnk("R", "PoissonSolverNodes", "vars/Hamiltonian.html#PoissonSolverNodes"))
 insDoc(aux1, gLnk("R", "PoissonSolverPSolverParallelData", "vars/Hamiltonian.html#PoissonSolverPSolverParallelData"))
 insDoc(aux1, gLnk("R", "PoissonSolverThreshold", "vars/Hamiltonian.html#PoissonSolverThreshold"))
+insDoc(aux1, gLnk("R", "PoissonTestPeriodicThreshold", "vars/Hamiltonian.html#PoissonTestPeriodicThreshold"))
 insDoc(aux1, gLnk("R", "Preconditioner", "vars/SCF.html#Preconditioner"))
 insDoc(aux1, gLnk("R", "PreconditionerFilterFactor", "vars/SCF.html#PreconditionerFilterFactor"))
 insDoc(aux1, gLnk("R", "PreconditionerIterationsMiddle", "vars/SCF.html#PreconditionerIterationsMiddle"))
@@ -522,7 +551,9 @@ insDoc(aux1, gLnk("R", "PreconditionerIterationsPre", "vars/SCF.html#Preconditio
 insDoc(aux1, gLnk("R", "Preorthogonalization", "vars/Linear_Response.html#Preorthogonalization"))
 insDoc(aux1, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
 insDoc(aux1, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
+insDoc(aux1, gLnk("R", "ProfilingOutputTree", "vars/Execution.html#ProfilingOutputTree"))
 insDoc(aux1, gLnk("R", "ProfilingOutputYAML", "vars/Execution.html#ProfilingOutputYAML"))
+insDoc(aux1, gLnk("R", "PropagateSpatialMaxwellField", "vars/MaxwellStates.html#PropagateSpatialMaxwellField"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumDampFactor", "vars/Utilities.html#PropagationSpectrumDampFactor"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumDampMode", "vars/Utilities.html#PropagationSpectrumDampMode"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#PropagationSpectrumEndTime"))
@@ -534,8 +565,6 @@ insDoc(aux1, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#Prop
 insDoc(aux1, gLnk("R", "PropagationSpectrumSymmetrizeSigma", "vars/Utilities.html#PropagationSpectrumSymmetrizeSigma"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
-insDoc(aux1, gLnk("R", "PseudopotentialAutomaticParameters", "vars/System.html#PseudopotentialAutomaticParameters"))
-insDoc(aux1, gLnk("R", "PseudopotentialEnergyTolerance", "vars/System.html#PseudopotentialEnergyTolerance"))
 insDoc(aux1, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
 aux1 = insFld(aux0, gFld("Q", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "QPointsGrid", "vars/Mesh.html#QPointsGrid"))
@@ -557,21 +586,18 @@ insDoc(aux1, gLnk("R", "ResponseMethod", "vars/Linear_Response.html#ResponseMeth
 insDoc(aux1, gLnk("R", "RestartFixedOccupations", "vars/States.html#RestartFixedOccupations"))
 insDoc(aux1, gLnk("R", "RestartOptions", "vars/Execution.html#RestartOptions"))
 insDoc(aux1, gLnk("R", "RestartReorderOccs", "vars/States.html#RestartReorderOccs"))
+insDoc(aux1, gLnk("R", "RestartWallTimePeriod", "vars/Execution.html#RestartWallTimePeriod"))
 insDoc(aux1, gLnk("R", "RestartWrite", "vars/Execution.html#RestartWrite"))
 insDoc(aux1, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWriteInterval"))
 insDoc(aux1, gLnk("R", "RestartWriteTime", "vars/Execution.html#RestartWriteTime"))
 insDoc(aux1, gLnk("R", "RiemannSilbersteinSign", "vars/Hamiltonian.html#RiemannSilbersteinSign"))
 insDoc(aux1, gLnk("R", "RootSolver", "vars/Math.html#RootSolver"))
 insDoc(aux1, gLnk("R", "RootSolverAbsTolerance", "vars/Math.html#RootSolverAbsTolerance"))
-insDoc(aux1, gLnk("R", "RootSolverHavePolynomial", "vars/Math.html#RootSolverHavePolynomial"))
 insDoc(aux1, gLnk("R", "RootSolverMaxIter", "vars/Math.html#RootSolverMaxIter"))
 insDoc(aux1, gLnk("R", "RootSolverRelTolerance", "vars/Math.html#RootSolverRelTolerance"))
-insDoc(aux1, gLnk("R", "RootSolverWSRadius", "vars/Math.html#RootSolverWSRadius"))
 aux1 = insFld(aux0, gFld("S", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
-insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
-insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
-insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
+insDoc(aux1, gLnk("R", "SccTolerance", "vars/DFTBPlusInterface.html#SccTolerance"))
 insDoc(aux1, gLnk("R", "SCDMmu", "vars/Utilities.html#SCDMmu"))
 insDoc(aux1, gLnk("R", "SCDMsigma", "vars/Utilities.html#SCDMsigma"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
@@ -581,6 +607,7 @@ insDoc(aux1, gLnk("R", "SCFCalculateStress", "vars/SCF.html#SCFCalculateStress")
 insDoc(aux1, gLnk("R", "SCFinLCAO", "vars/SCF.html#SCFinLCAO"))
 insDoc(aux1, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux1, gLnk("R", "SkipSOrbitals", "vars/Hamiltonian.html#SkipSOrbitals"))
+insDoc(aux1, gLnk("R", "SlakoDir", "vars/Execution.html#SlakoDir"))
 insDoc(aux1, gLnk("R", "Smearing", "vars/States.html#Smearing"))
 insDoc(aux1, gLnk("R", "SmearingFunction", "vars/States.html#SmearingFunction"))
 insDoc(aux1, gLnk("R", "SmearingMPOrder", "vars/States.html#SmearingMPOrder"))
@@ -606,12 +633,15 @@ insDoc(aux1, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogona
 insDoc(aux1, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
 insDoc(aux1, gLnk("R", "StatesRandomization", "vars/States.html#StatesRandomization"))
 insDoc(aux1, gLnk("R", "StaticElectricField", "vars/Hamiltonian.html#StaticElectricField"))
+insDoc(aux1, gLnk("R", "StaticExternalPotentials", "vars/System.html#StaticExternalPotentials"))
 insDoc(aux1, gLnk("R", "StaticMagneticField", "vars/Hamiltonian.html#StaticMagneticField"))
 insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#StaticMagneticField2DGauge"))
 insDoc(aux1, gLnk("R", "stderr", "vars/Execution.html#stderr"))
 insDoc(aux1, gLnk("R", "stdout", "vars/Execution.html#stdout"))
 insDoc(aux1, gLnk("R", "SubspaceDiagonalization", "vars/SCF.html#SubspaceDiagonalization"))
+insDoc(aux1, gLnk("R", "SupercellDimensions", "vars/Utilities.html#SupercellDimensions"))
 insDoc(aux1, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
+insDoc(aux1, gLnk("R", "SymmetriesTolerance", "vars/Execution.html#SymmetriesTolerance"))
 insDoc(aux1, gLnk("R", "SymmetrizeDensity", "vars/States.html#SymmetrizeDensity"))
 insDoc(aux1, gLnk("R", "SymmetrizeDynamicalMatrix", "vars/Linear_Response.html#SymmetrizeDynamicalMatrix"))
 insDoc(aux1, gLnk("R", "SymmetryBreakDir", "vars/Mesh.html#SymmetryBreakDir"))
@@ -641,14 +671,14 @@ insDoc(aux1, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTime
 insDoc(aux1, gLnk("R", "TDKickFunction", "vars/Time-Dependent.html#TDKickFunction"))
 insDoc(aux1, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
 insDoc(aux1, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
-insDoc(aux1, gLnk("R", "TDMaxwellKSRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellKSRelaxationSteps"))
-insDoc(aux1, gLnk("R", "TDMaxwellTDRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellTDRelaxationSteps"))
 insDoc(aux1, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentumTransfer"))
 insDoc(aux1, gLnk("R", "TDMultipleMomentumTransfer", "vars/Time-Dependent.html#TDMultipleMomentumTransfer"))
 insDoc(aux1, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
 insDoc(aux1, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
 insDoc(aux1, gLnk("R", "TDOutputComputeInterval", "vars/Time-Dependent.html#TDOutputComputeInterval"))
 insDoc(aux1, gLnk("R", "TDOutputDFTU", "vars/Time-Dependent.html#TDOutputDFTU"))
+insDoc(aux1, gLnk("R", "TDOutputResolveStates", "vars/Time-Dependent.html#TDOutputResolveStates"))
+insDoc(aux1, gLnk("R", "TDPhotonicTimeScale", "vars/Time-Dependent.html#TDPhotonicTimeScale"))
 insDoc(aux1, gLnk("R", "TDPolarization", "vars/Time-Dependent.html#TDPolarization"))
 insDoc(aux1, gLnk("R", "TDPolarizationDirection", "vars/Time-Dependent.html#TDPolarizationDirection"))
 insDoc(aux1, gLnk("R", "TDPolarizationEquivAxes", "vars/Time-Dependent.html#TDPolarizationEquivAxes"))
@@ -656,19 +686,23 @@ insDoc(aux1, gLnk("R", "TDPolarizationWprime", "vars/Time-Dependent.html#TDPolar
 insDoc(aux1, gLnk("R", "TDProjStateStart", "vars/Time-Dependent.html#TDProjStateStart"))
 insDoc(aux1, gLnk("R", "TDPropagationTime", "vars/Time-Dependent.html#TDPropagationTime"))
 insDoc(aux1, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
+insDoc(aux1, gLnk("R", "TDReducedMomentumTransfer", "vars/Time-Dependent.html#TDReducedMomentumTransfer"))
 insDoc(aux1, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
 insDoc(aux1, gLnk("R", "TDScissor", "vars/Time-Dependent.html#TDScissor"))
 insDoc(aux1, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
 insDoc(aux1, gLnk("R", "TDSystemPropagator", "vars/Time-Dependent.html#TDSystemPropagator"))
+insDoc(aux1, gLnk("R", "TDTDMFrequencies", "vars/Utilities.html#TDTDMFrequencies"))
+insDoc(aux1, gLnk("R", "TDTDMHoleCoordinates", "vars/Utilities.html#TDTDMHoleCoordinates"))
+insDoc(aux1, gLnk("R", "TDTDMHoleReducedCoordinates", "vars/Utilities.html#TDTDMHoleReducedCoordinates"))
 insDoc(aux1, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
 insDoc(aux1, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
-insDoc(aux1, gLnk("R", "TestBatchOps", "vars/Utilities.html#TestBatchOps"))
-insDoc(aux1, gLnk("R", "TestHamiltonianApply", "vars/Utilities.html#TestHamiltonianApply"))
-insDoc(aux1, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
-insDoc(aux1, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
-insDoc(aux1, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
-insDoc(aux1, gLnk("R", "TestRepetitions", "vars/Utilities.html#TestRepetitions"))
-insDoc(aux1, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
+insDoc(aux1, gLnk("R", "TestBatchOps", "vars/Calculation_Modes.html#TestBatchOps"))
+insDoc(aux1, gLnk("R", "TestHamiltonianApply", "vars/Calculation_Modes.html#TestHamiltonianApply"))
+insDoc(aux1, gLnk("R", "TestMaxBlockSize", "vars/Calculation_Modes.html#TestMaxBlockSize"))
+insDoc(aux1, gLnk("R", "TestMinBlockSize", "vars/Calculation_Modes.html#TestMinBlockSize"))
+insDoc(aux1, gLnk("R", "TestMode", "vars/Calculation_Modes.html#TestMode"))
+insDoc(aux1, gLnk("R", "TestRepetitions", "vars/Calculation_Modes.html#TestRepetitions"))
+insDoc(aux1, gLnk("R", "TestType", "vars/Calculation_Modes.html#TestType"))
 insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
 insDoc(aux1, gLnk("R", "Thermostat", "vars/Time-Dependent.html#Thermostat"))
 insDoc(aux1, gLnk("R", "ThermostatMass", "vars/Time-Dependent.html#ThermostatMass"))
@@ -676,6 +710,7 @@ insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
 insDoc(aux1, gLnk("R", "TotalStates", "vars/States.html#TotalStates"))
 insDoc(aux1, gLnk("R", "TransformStates", "vars/States.html#TransformStates"))
 insDoc(aux1, gLnk("R", "TransientAbsorptionReference", "vars/Utilities.html#TransientAbsorptionReference"))
+insDoc(aux1, gLnk("R", "TransientMagnetizationReference", "vars/Utilities.html#TransientMagnetizationReference"))
 aux1 = insFld(aux0, gFld("U", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "UnfoldEnergyStep", "vars/Utilities.html#UnfoldEnergyStep"))
 insDoc(aux1, gLnk("R", "UnfoldKPointsPath", "vars/Utilities.html#UnfoldKPointsPath"))
@@ -690,8 +725,7 @@ insDoc(aux1, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
 insDoc(aux1, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
 insDoc(aux1, gLnk("R", "UnoccUseTD", "vars/Calculation_Modes.html#UnoccUseTD"))
 insDoc(aux1, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtomicOrbitals"))
-insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
-insDoc(aux1, gLnk("R", "UserDefinedConstantSpacialMaxwellField", "vars/MaxwellStates.html#UserDefinedConstantSpacialMaxwellField"))
+insDoc(aux1, gLnk("R", "UserDefinedConstantSpatialMaxwellField", "vars/MaxwellStates.html#UserDefinedConstantSpatialMaxwellField"))
 insDoc(aux1, gLnk("R", "UserDefinedInitialMaxwellStates", "vars/MaxwellStates.html#UserDefinedInitialMaxwellStates"))
 insDoc(aux1, gLnk("R", "UserDefinedMaxwellExternalCurrent", "vars/MaxwellStates.html#UserDefinedMaxwellExternalCurrent"))
 insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
@@ -714,8 +748,6 @@ insDoc(aux1, gLnk("R", "Wannier90Mode", "vars/Utilities.html#Wannier90Mode"))
 insDoc(aux1, gLnk("R", "Wannier90Prefix", "vars/Utilities.html#Wannier90Prefix"))
 insDoc(aux1, gLnk("R", "Wannier90UseSCDM", "vars/Utilities.html#Wannier90UseSCDM"))
 insDoc(aux1, gLnk("R", "Wannier90UseTD", "vars/Utilities.html#Wannier90UseTD"))
-insDoc(aux1, gLnk("R", "WatterstromODESolver", "vars/Math.html#WatterstromODESolver"))
-insDoc(aux1, gLnk("R", "WatterstromODESolverNSteps", "vars/Math.html#WatterstromODESolverNSteps"))
 insDoc(aux1, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
 aux1 = insFld(aux0, gFld("X", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Xalpha", "vars/Hamiltonian.html#Xalpha"))
