@@ -8,7 +8,7 @@ foldersTree = aux0
 aux1 = insFld(aux0, gFld("Atomic Orbitals", "vars/Atomic_Orbitals.html#Atomic_Orbitals"))
 insDoc(aux1, gLnk("R", "AOLoewdin", "vars/Atomic_Orbitals.html#AOLoewdin"))
 insDoc(aux1, gLnk("R", "AONormalize", "vars/Atomic_Orbitals.html#AONormalize"))
-insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Atomic_Orbitals.html#AOSubmeshForPeriodic"))
+insDoc(aux1, gLnk("R", "AOSubmesh", "vars/Atomic_Orbitals.html#AOSubmesh"))
 insDoc(aux1, gLnk("R", "AOThreshold", "vars/Atomic_Orbitals.html#AOThreshold"))
 insDoc(aux1, gLnk("R", "AOTruncation", "vars/Atomic_Orbitals.html#AOTruncation"))
 aux1 = insFld(aux0, gFld("Calculation Modes", "vars/Calculation_Modes.html#Calculation_Modes"))
@@ -83,20 +83,33 @@ insDoc(aux2, gLnk("R", "OCTTargetUserdefined", "vars/Calculation_Modes.html#OCTT
 insDoc(aux2, gLnk("R", "OCTTdTarget", "vars/Calculation_Modes.html#OCTTdTarget"))
 insDoc(aux2, gLnk("R", "OCTVelocityDerivatives", "vars/Calculation_Modes.html#OCTVelocityDerivatives"))
 insDoc(aux2, gLnk("R", "OCTVelocityTarget", "vars/Calculation_Modes.html#OCTVelocityTarget"))
+aux2 = insFld(aux1, gFld("Test", "vars/Calculation_Modes.html#Calculation_Modes::Test"))
+insDoc(aux2, gLnk("R", "InterpolationTestOrder", "vars/Calculation_Modes.html#InterpolationTestOrder"))
+insDoc(aux2, gLnk("R", "TestBatchOps", "vars/Calculation_Modes.html#TestBatchOps"))
+insDoc(aux2, gLnk("R", "TestHamiltonianApply", "vars/Calculation_Modes.html#TestHamiltonianApply"))
+insDoc(aux2, gLnk("R", "TestMaxBlockSize", "vars/Calculation_Modes.html#TestMaxBlockSize"))
+insDoc(aux2, gLnk("R", "TestMinBlockSize", "vars/Calculation_Modes.html#TestMinBlockSize"))
+insDoc(aux2, gLnk("R", "TestMode", "vars/Calculation_Modes.html#TestMode"))
+insDoc(aux2, gLnk("R", "TestRepetitions", "vars/Calculation_Modes.html#TestRepetitions"))
+insDoc(aux2, gLnk("R", "TestType", "vars/Calculation_Modes.html#TestType"))
 aux2 = insFld(aux1, gFld("Unoccupied States", "vars/Calculation_Modes.html#Calculation_Modes::Unoccupied_States"))
 insDoc(aux2, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
 insDoc(aux2, gLnk("R", "UnoccUseTD", "vars/Calculation_Modes.html#UnoccUseTD"))
 aux1 = insFld(aux0, gFld("ClassicalParticles", "vars/ClassicalParticles.html#ClassicalParticles"))
-insDoc(aux1, gLnk("R", "ClassicalParticleCharge", "vars/ClassicalParticles.html#ClassicalParticleCharge"))
-insDoc(aux1, gLnk("R", "ClassicalParticleInitialPosition", "vars/ClassicalParticles.html#ClassicalParticleInitialPosition"))
-insDoc(aux1, gLnk("R", "ClassicalParticleInitialVelocity", "vars/ClassicalParticles.html#ClassicalParticleInitialVelocity"))
-insDoc(aux1, gLnk("R", "ClassicalParticleMass", "vars/ClassicalParticles.html#ClassicalParticleMass"))
+insDoc(aux1, gLnk("R", "ParticleCharge", "vars/ClassicalParticles.html#ParticleCharge"))
+insDoc(aux1, gLnk("R", "ParticleInitialPosition", "vars/ClassicalParticles.html#ParticleInitialPosition"))
+insDoc(aux1, gLnk("R", "ParticleInitialVelocity", "vars/ClassicalParticles.html#ParticleInitialVelocity"))
+aux1 = insFld(aux0, gFld("DFTBPlusInterface", "vars/DFTBPlusInterface.html#DFTBPlusInterface"))
+insDoc(aux1, gLnk("R", "InitialIonicTemperature", "vars/DFTBPlusInterface.html#InitialIonicTemperature"))
+insDoc(aux1, gLnk("R", "MaxAngularMomentum", "vars/DFTBPlusInterface.html#MaxAngularMomentum"))
+insDoc(aux1, gLnk("R", "SccTolerance", "vars/DFTBPlusInterface.html#SccTolerance"))
 aux1 = insFld(aux0, gFld("Execution", "vars/Execution.html#Execution"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
 aux2 = insFld(aux1, gFld("Accel", "vars/Execution.html#Execution::Accel"))
 insDoc(aux2, gLnk("R", "AccelBenchmark", "vars/Execution.html#AccelBenchmark"))
 insDoc(aux2, gLnk("R", "AccelDevice", "vars/Execution.html#AccelDevice"))
 insDoc(aux2, gLnk("R", "AccelPlatform", "vars/Execution.html#AccelPlatform"))
+insDoc(aux2, gLnk("R", "AllowCPUonly", "vars/Execution.html#AllowCPUonly"))
 insDoc(aux2, gLnk("R", "CudaAwareMPI", "vars/Execution.html#CudaAwareMPI"))
 insDoc(aux2, gLnk("R", "DisableAccel", "vars/Execution.html#DisableAccel"))
 aux2 = insFld(aux1, gFld("Debug", "vars/Execution.html#Execution::Debug"))
@@ -107,12 +120,13 @@ insDoc(aux2, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
 insDoc(aux2, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
 insDoc(aux2, gLnk("R", "ReportMemory", "vars/Execution.html#ReportMemory"))
 aux2 = insFld(aux1, gFld("IO", "vars/Execution.html#Execution::IO"))
-insDoc(aux2, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
 insDoc(aux2, gLnk("R", "MaxwellRestartWriteInterval", "vars/Execution.html#MaxwellRestartWriteInterval"))
 insDoc(aux2, gLnk("R", "RestartOptions", "vars/Execution.html#RestartOptions"))
+insDoc(aux2, gLnk("R", "RestartWallTimePeriod", "vars/Execution.html#RestartWallTimePeriod"))
 insDoc(aux2, gLnk("R", "RestartWrite", "vars/Execution.html#RestartWrite"))
 insDoc(aux2, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWriteInterval"))
 insDoc(aux2, gLnk("R", "RestartWriteTime", "vars/Execution.html#RestartWriteTime"))
+insDoc(aux2, gLnk("R", "SlakoDir", "vars/Execution.html#SlakoDir"))
 insDoc(aux2, gLnk("R", "Walltime", "vars/Execution.html#Walltime"))
 insDoc(aux2, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
 insDoc(aux2, gLnk("R", "stderr", "vars/Execution.html#stderr"))
@@ -120,7 +134,11 @@ insDoc(aux2, gLnk("R", "stdout", "vars/Execution.html#stdout"))
 aux2 = insFld(aux1, gFld("Optimization", "vars/Execution.html#Execution::Optimization"))
 insDoc(aux2, gLnk("R", "HamiltonianApplyPacked", "vars/Execution.html#HamiltonianApplyPacked"))
 insDoc(aux2, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
+insDoc(aux2, gLnk("R", "MeshBlockDirection", "vars/Execution.html#MeshBlockDirection"))
 insDoc(aux2, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
+insDoc(aux2, gLnk("R", "MeshLocalBlockDirection", "vars/Execution.html#MeshLocalBlockDirection"))
+insDoc(aux2, gLnk("R", "MeshLocalBlockSize", "vars/Execution.html#MeshLocalBlockSize"))
+insDoc(aux2, gLnk("R", "MeshLocalOrder", "vars/Execution.html#MeshLocalOrder"))
 insDoc(aux2, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
 insDoc(aux2, gLnk("R", "NLOperatorCompactBoundaries", "vars/Execution.html#NLOperatorCompactBoundaries"))
 insDoc(aux2, gLnk("R", "OperateAccel", "vars/Execution.html#OperateAccel"))
@@ -130,6 +148,7 @@ insDoc(aux2, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
 insDoc(aux2, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
 insDoc(aux2, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
 insDoc(aux2, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
+insDoc(aux2, gLnk("R", "ProfilingOutputTree", "vars/Execution.html#ProfilingOutputTree"))
 insDoc(aux2, gLnk("R", "ProfilingOutputYAML", "vars/Execution.html#ProfilingOutputYAML"))
 insDoc(aux2, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
 insDoc(aux2, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
@@ -153,14 +172,17 @@ insDoc(aux2, gLnk("R", "ReorderRanks", "vars/Execution.html#ReorderRanks"))
 insDoc(aux2, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
 aux2 = insFld(aux1, gFld("Symmetries", "vars/Execution.html#Execution::Symmetries"))
 insDoc(aux2, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
+insDoc(aux2, gLnk("R", "SymmetriesTolerance", "vars/Execution.html#SymmetriesTolerance"))
 aux2 = insFld(aux1, gFld("Units", "vars/Execution.html#Execution::Units"))
 insDoc(aux2, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux2, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
 insDoc(aux2, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
 aux1 = insFld(aux0, gFld("Hamiltonian", "vars/Hamiltonian.html#Hamiltonian"))
+insDoc(aux1, gLnk("R", "AdaptivelyCompressedExchange", "vars/Hamiltonian.html#AdaptivelyCompressedExchange"))
 insDoc(aux1, gLnk("R", "CalculateSelfInducedMagneticField", "vars/Hamiltonian.html#CalculateSelfInducedMagneticField"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
 insDoc(aux1, gLnk("R", "CurrentDensity", "vars/Hamiltonian.html#CurrentDensity"))
+insDoc(aux1, gLnk("R", "EnablePhotons", "vars/Hamiltonian.html#EnablePhotons"))
 insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
 insDoc(aux1, gLnk("R", "ExternalCurrent", "vars/Hamiltonian.html#ExternalCurrent"))
 insDoc(aux1, gLnk("R", "FilterPotentials", "vars/Hamiltonian.html#FilterPotentials"))
@@ -170,7 +192,8 @@ insDoc(aux1, gLnk("R", "GaugeFieldDynamics", "vars/Hamiltonian.html#GaugeFieldDy
 insDoc(aux1, gLnk("R", "GaugeFieldPropagate", "vars/Hamiltonian.html#GaugeFieldPropagate"))
 insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorField"))
 insDoc(aux1, gLnk("R", "GyromagneticRatio", "vars/Hamiltonian.html#GyromagneticRatio"))
-insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
+insDoc(aux1, gLnk("R", "MagneticConstrain", "vars/Hamiltonian.html#MagneticConstrain"))
+insDoc(aux1, gLnk("R", "MagneticConstrainStrength", "vars/Hamiltonian.html#MagneticConstrainStrength"))
 insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
 insDoc(aux1, gLnk("R", "MaxwellHamiltonianOperator", "vars/Hamiltonian.html#MaxwellHamiltonianOperator"))
 insDoc(aux1, gLnk("R", "MaxwellMediumCalculation", "vars/Hamiltonian.html#MaxwellMediumCalculation"))
@@ -178,9 +201,6 @@ insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
 insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
 insDoc(aux1, gLnk("R", "RelativisticCorrection", "vars/Hamiltonian.html#RelativisticCorrection"))
 insDoc(aux1, gLnk("R", "RiemannSilbersteinSign", "vars/Hamiltonian.html#RiemannSilbersteinSign"))
-insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
-insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
-insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
 insDoc(aux1, gLnk("R", "SOStrength", "vars/Hamiltonian.html#SOStrength"))
 insDoc(aux1, gLnk("R", "StaticElectricField", "vars/Hamiltonian.html#StaticElectricField"))
 insDoc(aux1, gLnk("R", "StaticMagneticField", "vars/Hamiltonian.html#StaticMagneticField"))
@@ -237,6 +257,7 @@ insDoc(aux2, gLnk("R", "PoissonSolverMaxIter", "vars/Hamiltonian.html#PoissonSol
 insDoc(aux2, gLnk("R", "PoissonSolverMaxMultipole", "vars/Hamiltonian.html#PoissonSolverMaxMultipole"))
 insDoc(aux2, gLnk("R", "PoissonSolverNodes", "vars/Hamiltonian.html#PoissonSolverNodes"))
 insDoc(aux2, gLnk("R", "PoissonSolverThreshold", "vars/Hamiltonian.html#PoissonSolverThreshold"))
+insDoc(aux2, gLnk("R", "PoissonTestPeriodicThreshold", "vars/Hamiltonian.html#PoissonTestPeriodicThreshold"))
 aux3 = insFld(aux2, gFld("Multigrid", "vars/Hamiltonian.html#Hamiltonian::Poisson::Multigrid"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGMaxCycles", "vars/Hamiltonian.html#PoissonSolverMGMaxCycles"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGPostsmoothingSteps", "vars/Hamiltonian.html#PoissonSolverMGPostsmoothingSteps"))
@@ -258,7 +279,6 @@ insDoc(aux2, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux2, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
 insDoc(aux2, gLnk("R", "OEPMixingScheme", "vars/Hamiltonian.html#OEPMixingScheme"))
 insDoc(aux2, gLnk("R", "PhotonModes", "vars/Hamiltonian.html#PhotonModes"))
-insDoc(aux2, gLnk("R", "Photons", "vars/Hamiltonian.html#Photons"))
 insDoc(aux2, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux2, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
 insDoc(aux2, gLnk("R", "VDWD3Functional", "vars/Hamiltonian.html#VDWD3Functional"))
@@ -288,15 +308,19 @@ insDoc(aux2, gLnk("R", "CasidaCalcForces", "vars/Linear_Response.html#CasidaCalc
 insDoc(aux2, gLnk("R", "CasidaCalcForcesKernel", "vars/Linear_Response.html#CasidaCalcForcesKernel"))
 insDoc(aux2, gLnk("R", "CasidaCalcForcesSCF", "vars/Linear_Response.html#CasidaCalcForcesSCF"))
 insDoc(aux2, gLnk("R", "CasidaCalcTriplet", "vars/Linear_Response.html#CasidaCalcTriplet"))
+insDoc(aux2, gLnk("R", "CasidaDistributedMatrix", "vars/Linear_Response.html#CasidaDistributedMatrix"))
 insDoc(aux2, gLnk("R", "CasidaHermitianConjugate", "vars/Linear_Response.html#CasidaHermitianConjugate"))
 insDoc(aux2, gLnk("R", "CasidaKSEnergyWindow", "vars/Linear_Response.html#CasidaKSEnergyWindow"))
 insDoc(aux2, gLnk("R", "CasidaKohnShamStates", "vars/Linear_Response.html#CasidaKohnShamStates"))
 insDoc(aux2, gLnk("R", "CasidaMomentumTransfer", "vars/Linear_Response.html#CasidaMomentumTransfer"))
+insDoc(aux2, gLnk("R", "CasidaParallelEigensolver", "vars/Linear_Response.html#CasidaParallelEigensolver"))
 insDoc(aux2, gLnk("R", "CasidaPrintExcitations", "vars/Linear_Response.html#CasidaPrintExcitations"))
 insDoc(aux2, gLnk("R", "CasidaQuadratureOrder", "vars/Linear_Response.html#CasidaQuadratureOrder"))
 insDoc(aux2, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux2, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
 insDoc(aux2, gLnk("R", "CasidaWeightThreshold", "vars/Linear_Response.html#CasidaWeightThreshold"))
+insDoc(aux2, gLnk("R", "CasidaWriteDistributedMatrix", "vars/Linear_Response.html#CasidaWriteDistributedMatrix"))
+insDoc(aux2, gLnk("R", "PhotonmodesFilename", "vars/Linear_Response.html#PhotonmodesFilename"))
 aux2 = insFld(aux1, gFld("KdotP", "vars/Linear_Response.html#Linear_Response::KdotP"))
 insDoc(aux2, gLnk("R", "KdotPCalcSecondOrder", "vars/Linear_Response.html#KdotPCalcSecondOrder"))
 insDoc(aux2, gLnk("R", "KdotPCalculateEffectiveMasses", "vars/Linear_Response.html#KdotPCalculateEffectiveMasses"))
@@ -340,6 +364,7 @@ insDoc(aux2, gLnk("R", "EMVerbose", "vars/Linear_Response.html#EMVerbose"))
 insDoc(aux2, gLnk("R", "EMWriteRestartDensities", "vars/Linear_Response.html#EMWriteRestartDensities"))
 aux2 = insFld(aux1, gFld("Sternheimer", "vars/Linear_Response.html#Linear_Response::Sternheimer"))
 insDoc(aux2, gLnk("R", "HamiltonianVariation", "vars/Linear_Response.html#HamiltonianVariation"))
+insDoc(aux2, gLnk("R", "PhotonEta", "vars/Linear_Response.html#PhotonEta"))
 insDoc(aux2, gLnk("R", "Preorthogonalization", "vars/Linear_Response.html#Preorthogonalization"))
 aux2 = insFld(aux1, gFld("Vibrational Modes", "vars/Linear_Response.html#Linear_Response::Vibrational_Modes"))
 insDoc(aux2, gLnk("R", "CalcInfrared", "vars/Linear_Response.html#CalcInfrared"))
@@ -350,12 +375,8 @@ aux1 = insFld(aux0, gFld("Math", "vars/Math.html#Math::RootSolver"))
 aux2 = insFld(aux1, gFld("RootSolver", "vars/Math.html#Math::RootSolver"))
 insDoc(aux2, gLnk("R", "RootSolver", "vars/Math.html#RootSolver"))
 insDoc(aux2, gLnk("R", "RootSolverAbsTolerance", "vars/Math.html#RootSolverAbsTolerance"))
-insDoc(aux2, gLnk("R", "RootSolverHavePolynomial", "vars/Math.html#RootSolverHavePolynomial"))
 insDoc(aux2, gLnk("R", "RootSolverMaxIter", "vars/Math.html#RootSolverMaxIter"))
 insDoc(aux2, gLnk("R", "RootSolverRelTolerance", "vars/Math.html#RootSolverRelTolerance"))
-insDoc(aux2, gLnk("R", "RootSolverWSRadius", "vars/Math.html#RootSolverWSRadius"))
-insDoc(aux2, gLnk("R", "WatterstromODESolver", "vars/Math.html#WatterstromODESolver"))
-insDoc(aux2, gLnk("R", "WatterstromODESolverNSteps", "vars/Math.html#WatterstromODESolverNSteps"))
 aux2 = insFld(aux1, gFld("SPARSKIT", "vars/Math.html#Math::SPARSKIT"))
 insDoc(aux2, gLnk("R", "SPARSKITAbsTolerance", "vars/Math.html#SPARSKITAbsTolerance"))
 insDoc(aux2, gLnk("R", "SPARSKITIterOut", "vars/Math.html#SPARSKITIterOut"))
@@ -364,21 +385,34 @@ insDoc(aux2, gLnk("R", "SPARSKITMaxIter", "vars/Math.html#SPARSKITMaxIter"))
 insDoc(aux2, gLnk("R", "SPARSKITRelTolerance", "vars/Math.html#SPARSKITRelTolerance"))
 insDoc(aux2, gLnk("R", "SPARSKITSolver", "vars/Math.html#SPARSKITSolver"))
 insDoc(aux2, gLnk("R", "SPARSKITVerboseSolver", "vars/Math.html#SPARSKITVerboseSolver"))
+aux1 = insFld(aux0, gFld("Maxwell", "vars/Maxwell.html#Maxwell"))
+insDoc(aux1, gLnk("R", "CheckPointsMediumFromFile", "vars/Maxwell.html#CheckPointsMediumFromFile"))
+insDoc(aux1, gLnk("R", "LinearMediumBoxFile", "vars/Maxwell.html#LinearMediumBoxFile"))
+insDoc(aux1, gLnk("R", "LinearMediumBoxShape", "vars/Maxwell.html#LinearMediumBoxShape"))
+insDoc(aux1, gLnk("R", "LinearMediumBoxSize", "vars/Maxwell.html#LinearMediumBoxSize"))
+insDoc(aux1, gLnk("R", "LinearMediumEdgeProfile", "vars/Maxwell.html#LinearMediumEdgeProfile"))
+insDoc(aux1, gLnk("R", "LinearMediumProperties", "vars/Maxwell.html#LinearMediumProperties"))
+insDoc(aux1, gLnk("R", "MediumCurrentCoordinates", "vars/Maxwell.html#MediumCurrentCoordinates"))
+insDoc(aux1, gLnk("R", "MediumDispersionType", "vars/Maxwell.html#MediumDispersionType"))
+insDoc(aux1, gLnk("R", "MediumPoleDamping", "vars/Maxwell.html#MediumPoleDamping"))
+insDoc(aux1, gLnk("R", "MediumPoleEnergy", "vars/Maxwell.html#MediumPoleEnergy"))
+insDoc(aux1, gLnk("R", "MediumPoleStrength", "vars/Maxwell.html#MediumPoleStrength"))
+insDoc(aux1, gLnk("R", "PlaneWavesOnOneSide", "vars/Maxwell.html#PlaneWavesOnOneSide"))
+insDoc(aux1, gLnk("R", "PlaneWavesSide", "vars/Maxwell.html#PlaneWavesSide"))
+aux2 = insFld(aux1, gFld("Coordinates", "vars/Maxwell.html#Maxwell::Coordinates"))
+insDoc(aux2, gLnk("R", "MaxwellFieldsCoordinate", "vars/Maxwell.html#MaxwellFieldsCoordinate"))
 aux1 = insFld(aux0, gFld("MaxwellStates", "vars/MaxwellStates.html#MaxwellStates"))
 insDoc(aux1, gLnk("R", "MaxwellIncidentWaves", "vars/MaxwellStates.html#MaxwellIncidentWaves"))
-insDoc(aux1, gLnk("R", "UserDefinedConstantSpacialMaxwellField", "vars/MaxwellStates.html#UserDefinedConstantSpacialMaxwellField"))
+insDoc(aux1, gLnk("R", "PropagateSpatialMaxwellField", "vars/MaxwellStates.html#PropagateSpatialMaxwellField"))
+insDoc(aux1, gLnk("R", "UserDefinedConstantSpatialMaxwellField", "vars/MaxwellStates.html#UserDefinedConstantSpatialMaxwellField"))
 insDoc(aux1, gLnk("R", "UserDefinedInitialMaxwellStates", "vars/MaxwellStates.html#UserDefinedInitialMaxwellStates"))
 insDoc(aux1, gLnk("R", "UserDefinedMaxwellExternalCurrent", "vars/MaxwellStates.html#UserDefinedMaxwellExternalCurrent"))
 aux1 = insFld(aux0, gFld("Mesh", "vars/Mesh.html#Mesh"))
-insDoc(aux1, gLnk("R", "DoubleGrid", "vars/Mesh.html#DoubleGrid"))
-insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
-insDoc(aux1, gLnk("R", "MultiResolutionArea", "vars/Mesh.html#MultiResolutionArea"))
-insDoc(aux1, gLnk("R", "MultiResolutionInterpolationOrder", "vars/Mesh.html#MultiResolutionInterpolationOrder"))
+insDoc(aux1, gLnk("R", "MeshIndexType", "vars/Mesh.html#MeshIndexType"))
 insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
 insDoc(aux1, gLnk("R", "PeriodicBoundaryMask", "vars/Mesh.html#PeriodicBoundaryMask"))
 insDoc(aux1, gLnk("R", "Spacing", "vars/Mesh.html#Spacing"))
 insDoc(aux1, gLnk("R", "SpiralBoundaryCondition", "vars/Mesh.html#SpiralBoundaryCondition"))
-insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 aux2 = insFld(aux1, gFld("Curvilinear", "vars/Mesh.html#Mesh::Curvilinear"))
 insDoc(aux2, gLnk("R", "CurvMethod", "vars/Mesh.html#CurvMethod"))
 aux3 = insFld(aux2, gFld("Gygi", "vars/Mesh.html#Mesh::Curvilinear::Gygi"))
@@ -432,6 +466,8 @@ insDoc(aux1, gLnk("R", "DOSEnergyMin", "vars/Output.html#DOSEnergyMin"))
 insDoc(aux1, gLnk("R", "DOSEnergyPoints", "vars/Output.html#DOSEnergyPoints"))
 insDoc(aux1, gLnk("R", "DOSGamma", "vars/Output.html#DOSGamma"))
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
+insDoc(aux1, gLnk("R", "LinearMediumOutput", "vars/Output.html#LinearMediumOutput"))
+insDoc(aux1, gLnk("R", "LinearMediumOutputDir", "vars/Output.html#LinearMediumOutputDir"))
 insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#LocalMagneticMomentsSphereRadius"))
 insDoc(aux1, gLnk("R", "MaxwellOutput", "vars/Output.html#MaxwellOutput"))
 insDoc(aux1, gLnk("R", "MaxwellOutputInterval", "vars/Output.html#MaxwellOutputInterval"))
@@ -442,13 +478,11 @@ insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
 insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
-insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
 insDoc(aux1, gLnk("R", "OutputMEEnd", "vars/Output.html#OutputMEEnd"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
 insDoc(aux1, gLnk("R", "OutputMEStart", "vars/Output.html#OutputMEStart"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
-insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
 aux2 = insFld(aux1, gFld("BerkeleyGW", "vars/Output.html#Output::BerkeleyGW"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_CalcDipoleMtxels", "vars/Output.html#BerkeleyGW_CalcDipoleMtxels"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_CalcExchange", "vars/Output.html#BerkeleyGW_CalcExchange"))
@@ -462,7 +496,6 @@ insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmax", "vars/Output.html#Berkeley
 insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmin", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmin"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_WFN_filename", "vars/Output.html#BerkeleyGW_WFN_filename"))
 aux1 = insFld(aux0, gFld("SCF", "vars/SCF.html#SCF"))
-insDoc(aux1, gLnk("R", "CalcEigenvalues", "vars/SCF.html#CalcEigenvalues"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
 insDoc(aux1, gLnk("R", "SCFCalculateForces", "vars/SCF.html#SCFCalculateForces"))
 insDoc(aux1, gLnk("R", "SCFCalculatePartialCharges", "vars/SCF.html#SCFCalculatePartialCharges"))
@@ -473,7 +506,6 @@ insDoc(aux2, gLnk("R", "ConvAbsDens", "vars/SCF.html#ConvAbsDens"))
 insDoc(aux2, gLnk("R", "ConvAbsEv", "vars/SCF.html#ConvAbsEv"))
 insDoc(aux2, gLnk("R", "ConvEigenError", "vars/SCF.html#ConvEigenError"))
 insDoc(aux2, gLnk("R", "ConvEnergy", "vars/SCF.html#ConvEnergy"))
-insDoc(aux2, gLnk("R", "ConvForce", "vars/SCF.html#ConvForce"))
 insDoc(aux2, gLnk("R", "ConvRelDens", "vars/SCF.html#ConvRelDens"))
 insDoc(aux2, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
 insDoc(aux2, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
@@ -515,6 +547,7 @@ insDoc(aux2, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
 insDoc(aux2, gLnk("R", "Mixing", "vars/SCF.html#Mixing"))
 insDoc(aux2, gLnk("R", "MixingPreconditioner", "vars/SCF.html#MixingPreconditioner"))
 insDoc(aux2, gLnk("R", "MixingResidual", "vars/SCF.html#MixingResidual"))
+insDoc(aux2, gLnk("R", "MixingRestart", "vars/SCF.html#MixingRestart"))
 insDoc(aux2, gLnk("R", "MixingScheme", "vars/SCF.html#MixingScheme"))
 aux2 = insFld(aux1, gFld("RDMFT", "vars/SCF.html#SCF::RDMFT"))
 insDoc(aux2, gLnk("R", "RDMBasis", "vars/SCF.html#RDMBasis"))
@@ -550,11 +583,12 @@ insDoc(aux2, gLnk("R", "NParticleModelmb", "vars/States.html#NParticleModelmb"))
 insDoc(aux2, gLnk("R", "NTypeParticleModelmb", "vars/States.html#NTypeParticleModelmb"))
 aux1 = insFld(aux0, gFld("System", "vars/System.html#System"))
 insDoc(aux1, gLnk("R", "Dimensions", "vars/System.html#Dimensions"))
+insDoc(aux1, gLnk("R", "Interactions", "vars/System.html#Interactions"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
+insDoc(aux1, gLnk("R", "StaticExternalPotentials", "vars/System.html#StaticExternalPotentials"))
 insDoc(aux1, gLnk("R", "Systems", "vars/System.html#Systems"))
 aux2 = insFld(aux1, gFld("Coordinates", "vars/System.html#System::Coordinates"))
 insDoc(aux2, gLnk("R", "Coordinates", "vars/System.html#Coordinates"))
-insDoc(aux2, gLnk("R", "MaxwellFieldsCoordinate", "vars/System.html#MaxwellFieldsCoordinate"))
 insDoc(aux2, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
 insDoc(aux2, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
 insDoc(aux2, gLnk("R", "ReducedCoordinates", "vars/System.html#ReducedCoordinates"))
@@ -562,8 +596,6 @@ insDoc(aux2, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
 insDoc(aux2, gLnk("R", "XSFCoordinatesAnimStep", "vars/System.html#XSFCoordinatesAnimStep"))
 insDoc(aux2, gLnk("R", "XYZCoordinates", "vars/System.html#XYZCoordinates"))
 aux2 = insFld(aux1, gFld("Species", "vars/System.html#System::Species"))
-insDoc(aux2, gLnk("R", "PseudopotentialAutomaticParameters", "vars/System.html#PseudopotentialAutomaticParameters"))
-insDoc(aux2, gLnk("R", "PseudopotentialEnergyTolerance", "vars/System.html#PseudopotentialEnergyTolerance"))
 insDoc(aux2, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
 insDoc(aux2, gLnk("R", "Species", "vars/System.html#Species"))
 insDoc(aux2, gLnk("R", "SpeciesProjectorSphereThreshold", "vars/System.html#SpeciesProjectorSphereThreshold"))
@@ -576,6 +608,7 @@ insDoc(aux2, gLnk("R", "XSFVelocities", "vars/System.html#XSFVelocities"))
 insDoc(aux2, gLnk("R", "XYZVelocities", "vars/System.html#XYZVelocities"))
 aux1 = insFld(aux0, gFld("Time-Dependent", "vars/Time-Dependent.html#Time-Dependent"))
 insDoc(aux1, gLnk("R", "MaxwellFunctions", "vars/Time-Dependent.html#MaxwellFunctions"))
+insDoc(aux1, gLnk("R", "MillerIndicesBasis", "vars/Time-Dependent.html#MillerIndicesBasis"))
 insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalFields"))
 insDoc(aux1, gLnk("R", "TDFreezeDFTUOccupations", "vars/Time-Dependent.html#TDFreezeDFTUOccupations"))
 insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
@@ -610,22 +643,28 @@ insDoc(aux2, gLnk("R", "PESMaskSpectEnergyMax", "vars/Time-Dependent.html#PESMas
 insDoc(aux2, gLnk("R", "PESMaskSpectEnergyStep", "vars/Time-Dependent.html#PESMaskSpectEnergyStep"))
 insDoc(aux2, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStartTime"))
 insDoc(aux2, gLnk("R", "PES_Flux_ARPES_grid", "vars/Time-Dependent.html#PES_Flux_ARPES_grid"))
-insDoc(aux2, gLnk("R", "PES_Flux_AvoidAB", "vars/Time-Dependent.html#PES_Flux_AvoidAB"))
-insDoc(aux2, gLnk("R", "PES_Flux_BZones", "vars/Time-Dependent.html#PES_Flux_BZones"))
+insDoc(aux2, gLnk("R", "PES_Flux_AnisotropyCorrection", "vars/Time-Dependent.html#PES_Flux_AnisotropyCorrection"))
 insDoc(aux2, gLnk("R", "PES_Flux_DeltaK", "vars/Time-Dependent.html#PES_Flux_DeltaK"))
 insDoc(aux2, gLnk("R", "PES_Flux_EnergyGrid", "vars/Time-Dependent.html#PES_Flux_EnergyGrid"))
-insDoc(aux2, gLnk("R", "PES_Flux_Gpoint_Upsample", "vars/Time-Dependent.html#PES_Flux_Gpoint_Upsample"))
+insDoc(aux2, gLnk("R", "PES_Flux_Face_Dens", "vars/Time-Dependent.html#PES_Flux_Face_Dens"))
+insDoc(aux2, gLnk("R", "PES_Flux_GridTransformMatrix", "vars/Time-Dependent.html#PES_Flux_GridTransformMatrix"))
 insDoc(aux2, gLnk("R", "PES_Flux_Kmax", "vars/Time-Dependent.html#PES_Flux_Kmax"))
+insDoc(aux2, gLnk("R", "PES_Flux_Kmin", "vars/Time-Dependent.html#PES_Flux_Kmin"))
 insDoc(aux2, gLnk("R", "PES_Flux_Lmax", "vars/Time-Dependent.html#PES_Flux_Lmax"))
 insDoc(aux2, gLnk("R", "PES_Flux_Lsize", "vars/Time-Dependent.html#PES_Flux_Lsize"))
+insDoc(aux2, gLnk("R", "PES_Flux_Momenutum_Grid", "vars/Time-Dependent.html#PES_Flux_Momenutum_Grid"))
 insDoc(aux2, gLnk("R", "PES_Flux_Offset", "vars/Time-Dependent.html#PES_Flux_Offset"))
+insDoc(aux2, gLnk("R", "PES_Flux_Parallelization", "vars/Time-Dependent.html#PES_Flux_Parallelization"))
+insDoc(aux2, gLnk("R", "PES_Flux_PhiK", "vars/Time-Dependent.html#PES_Flux_PhiK"))
 insDoc(aux2, gLnk("R", "PES_Flux_Radius", "vars/Time-Dependent.html#PES_Flux_Radius"))
+insDoc(aux2, gLnk("R", "PES_Flux_RuntimeOutput", "vars/Time-Dependent.html#PES_Flux_RuntimeOutput"))
 insDoc(aux2, gLnk("R", "PES_Flux_Shape", "vars/Time-Dependent.html#PES_Flux_Shape"))
 insDoc(aux2, gLnk("R", "PES_Flux_StepsPhiK", "vars/Time-Dependent.html#PES_Flux_StepsPhiK"))
 insDoc(aux2, gLnk("R", "PES_Flux_StepsPhiR", "vars/Time-Dependent.html#PES_Flux_StepsPhiR"))
 insDoc(aux2, gLnk("R", "PES_Flux_StepsThetaK", "vars/Time-Dependent.html#PES_Flux_StepsThetaK"))
 insDoc(aux2, gLnk("R", "PES_Flux_StepsThetaR", "vars/Time-Dependent.html#PES_Flux_StepsThetaR"))
-insDoc(aux2, gLnk("R", "PES_Flux_UseMemory", "vars/Time-Dependent.html#PES_Flux_UseMemory"))
+insDoc(aux2, gLnk("R", "PES_Flux_ThetaK", "vars/Time-Dependent.html#PES_Flux_ThetaK"))
+insDoc(aux2, gLnk("R", "PES_Flux_UseSymmetries", "vars/Time-Dependent.html#PES_Flux_UseSymmetries"))
 insDoc(aux2, gLnk("R", "PES_spm_DeltaOmega", "vars/Time-Dependent.html#PES_spm_DeltaOmega"))
 insDoc(aux2, gLnk("R", "PES_spm_OmegaMax", "vars/Time-Dependent.html#PES_spm_OmegaMax"))
 insDoc(aux2, gLnk("R", "PES_spm_Radius", "vars/Time-Dependent.html#PES_spm_Radius"))
@@ -636,13 +675,12 @@ insDoc(aux2, gLnk("R", "PES_spm_recipe", "vars/Time-Dependent.html#PES_spm_recip
 insDoc(aux2, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
 aux2 = insFld(aux1, gFld("Propagation", "vars/Time-Dependent.html#Time-Dependent::Propagation"))
 insDoc(aux2, gLnk("R", "ArnoldiOrthogonalization", "vars/Time-Dependent.html#ArnoldiOrthogonalization"))
+insDoc(aux2, gLnk("R", "InteractionTiming", "vars/Time-Dependent.html#InteractionTiming"))
 insDoc(aux2, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
 insDoc(aux2, gLnk("R", "IonsTimeDependentDisplacements", "vars/Time-Dependent.html#IonsTimeDependentDisplacements"))
 insDoc(aux2, gLnk("R", "MaxwellAbsorbingBoundaries", "vars/Time-Dependent.html#MaxwellAbsorbingBoundaries"))
 insDoc(aux2, gLnk("R", "MaxwellBoundaryConditions", "vars/Time-Dependent.html#MaxwellBoundaryConditions"))
-insDoc(aux2, gLnk("R", "MaxwellMediumBox", "vars/Time-Dependent.html#MaxwellMediumBox"))
 insDoc(aux2, gLnk("R", "MaxwellTDETRSApprox", "vars/Time-Dependent.html#MaxwellTDETRSApprox"))
-insDoc(aux2, gLnk("R", "MaxwellTDIntervalSteps", "vars/Time-Dependent.html#MaxwellTDIntervalSteps"))
 insDoc(aux2, gLnk("R", "MaxwellTDOperatorMethod", "vars/Time-Dependent.html#MaxwellTDOperatorMethod"))
 insDoc(aux2, gLnk("R", "MaxwellTDSCFThreshold", "vars/Time-Dependent.html#MaxwellTDSCFThreshold"))
 insDoc(aux2, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
@@ -654,8 +692,7 @@ insDoc(aux2, gLnk("R", "TDExponentialMethod", "vars/Time-Dependent.html#TDExpone
 insDoc(aux2, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
 insDoc(aux2, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
 insDoc(aux2, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
-insDoc(aux2, gLnk("R", "TDMaxwellKSRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellKSRelaxationSteps"))
-insDoc(aux2, gLnk("R", "TDMaxwellTDRelaxationSteps", "vars/Time-Dependent.html#TDMaxwellTDRelaxationSteps"))
+insDoc(aux2, gLnk("R", "TDPhotonicTimeScale", "vars/Time-Dependent.html#TDPhotonicTimeScale"))
 insDoc(aux2, gLnk("R", "TDPropagationTime", "vars/Time-Dependent.html#TDPropagationTime"))
 insDoc(aux2, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
 insDoc(aux2, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
@@ -673,6 +710,7 @@ insDoc(aux2, gLnk("R", "TDDeltaUserDefined", "vars/Time-Dependent.html#TDDeltaUs
 insDoc(aux2, gLnk("R", "TDKickFunction", "vars/Time-Dependent.html#TDKickFunction"))
 insDoc(aux2, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentumTransfer"))
 insDoc(aux2, gLnk("R", "TDMultipleMomentumTransfer", "vars/Time-Dependent.html#TDMultipleMomentumTransfer"))
+insDoc(aux2, gLnk("R", "TDReducedMomentumTransfer", "vars/Time-Dependent.html#TDReducedMomentumTransfer"))
 aux3 = insFld(aux2, gFld("Dipole", "vars/Time-Dependent.html#Time-Dependent::Response::Dipole"))
 insDoc(aux3, gLnk("R", "TDEasyAxis", "vars/Time-Dependent.html#TDEasyAxis"))
 insDoc(aux3, gLnk("R", "TDPolarization", "vars/Time-Dependent.html#TDPolarization"))
@@ -689,6 +727,7 @@ insDoc(aux2, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleL
 insDoc(aux2, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
 insDoc(aux2, gLnk("R", "TDOutputComputeInterval", "vars/Time-Dependent.html#TDOutputComputeInterval"))
 insDoc(aux2, gLnk("R", "TDOutputDFTU", "vars/Time-Dependent.html#TDOutputDFTU"))
+insDoc(aux2, gLnk("R", "TDOutputResolveStates", "vars/Time-Dependent.html#TDOutputResolveStates"))
 insDoc(aux2, gLnk("R", "TDProjStateStart", "vars/Time-Dependent.html#TDProjStateStart"))
 aux1 = insFld(aux0, gFld("Utilities", "vars/Utilities.html#Utilities::"))
 insDoc(aux1, gLnk("R", "Volume", "vars/Utilities.html#Volume"))
@@ -726,7 +765,6 @@ insDoc(aux2, gLnk("R", "ConvertSubtractFolder", "vars/Utilities.html#ConvertSubt
 aux2 = insFld(aux1, gFld("oct-local_multipoles", "vars/Utilities.html#Utilities::oct-local_multipoles"))
 insDoc(aux2, gLnk("R", "LDBaderThreshold", "vars/Utilities.html#LDBaderThreshold"))
 insDoc(aux2, gLnk("R", "LDEnd", "vars/Utilities.html#LDEnd"))
-insDoc(aux2, gLnk("R", "LDExtraWrite", "vars/Utilities.html#LDExtraWrite"))
 insDoc(aux2, gLnk("R", "LDFilename", "vars/Utilities.html#LDFilename"))
 insDoc(aux2, gLnk("R", "LDFolder", "vars/Utilities.html#LDFolder"))
 insDoc(aux2, gLnk("R", "LDIonicDipole", "vars/Utilities.html#LDIonicDipole"))
@@ -761,14 +799,13 @@ insDoc(aux2, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#Propagati
 insDoc(aux2, gLnk("R", "SpectrumMethod", "vars/Utilities.html#SpectrumMethod"))
 insDoc(aux2, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSignalNoise"))
 insDoc(aux2, gLnk("R", "TransientAbsorptionReference", "vars/Utilities.html#TransientAbsorptionReference"))
-aux2 = insFld(aux1, gFld("oct-test", "vars/Utilities.html#Utilities::oct-test"))
-insDoc(aux2, gLnk("R", "TestBatchOps", "vars/Utilities.html#TestBatchOps"))
-insDoc(aux2, gLnk("R", "TestHamiltonianApply", "vars/Utilities.html#TestHamiltonianApply"))
-insDoc(aux2, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
-insDoc(aux2, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
-insDoc(aux2, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
-insDoc(aux2, gLnk("R", "TestRepetitions", "vars/Utilities.html#TestRepetitions"))
-insDoc(aux2, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
+aux2 = insFld(aux1, gFld("oct-spin_susceptibility", "vars/Utilities.html#Utilities::oct-spin_susceptibility"))
+insDoc(aux2, gLnk("R", "TransientMagnetizationReference", "vars/Utilities.html#TransientMagnetizationReference"))
+aux2 = insFld(aux1, gFld("oct-tdtdm", "vars/Utilities.html#Utilities::oct-tdtdm"))
+insDoc(aux2, gLnk("R", "SupercellDimensions", "vars/Utilities.html#SupercellDimensions"))
+insDoc(aux2, gLnk("R", "TDTDMFrequencies", "vars/Utilities.html#TDTDMFrequencies"))
+insDoc(aux2, gLnk("R", "TDTDMHoleCoordinates", "vars/Utilities.html#TDTDMHoleCoordinates"))
+insDoc(aux2, gLnk("R", "TDTDMHoleReducedCoordinates", "vars/Utilities.html#TDTDMHoleReducedCoordinates"))
 aux2 = insFld(aux1, gFld("oct-unfold", "vars/Utilities.html#Utilities::oct-unfold"))
 insDoc(aux2, gLnk("R", "UnfoldEnergyStep", "vars/Utilities.html#UnfoldEnergyStep"))
 insDoc(aux2, gLnk("R", "UnfoldKPointsPath", "vars/Utilities.html#UnfoldKPointsPath"))
