@@ -178,10 +178,11 @@ subroutine qshep3 ( n, x, y, z, f, nq, nw, nr, lcell, lnext, xyzmin, &
 ! xyzdl =      local variables for xyzdel
 ! xyzmn =      local variables for xyzmin
 !
+  use iso_fortran_env
   implicit none
 !
-  integer n
-  integer nr
+  integer(int64) n
+  integer(int64) nr
 !
   real ( kind = 8 ) a(9,n)
   real ( kind = 8 ) av
@@ -192,30 +193,30 @@ subroutine qshep3 ( n, x, y, z, f, nq, nw, nr, lcell, lnext, xyzmin, &
   real ( kind = 8 ), parameter :: dtol = 0.01D+00
   real ( kind = 8 ) f(n)
   real ( kind = 8 ) fk
-  integer i
-  integer ib
-  integer ier
-  integer ierr
-  integer ip1
-  integer irm1
-  integer irow
-  integer j
-  integer jp1
-  integer k
-  integer lcell(nr,nr,nr)
-  integer lmax
-  integer lnext(n)
-  integer lnp
-  integer neq
-  integer nn
-  integer nnq
-  integer nnr
-  integer nnw
-  integer np
-  integer npts(40)
-  integer nq
-  integer nqwmax
-  integer nw
+  integer(int64) i
+  integer(int64) ib
+  integer(int64) ier
+  integer(int64) ierr
+  integer(int64) ip1
+  integer(int64) irm1
+  integer(int64) irow
+  integer(int64) j
+  integer(int64) jp1
+  integer(int64) k
+  integer(int64) lcell(nr,nr,nr)
+  integer(int64) lmax
+  integer(int64) lnext(n)
+  integer(int64) lnp
+  integer(int64) neq
+  integer(int64) nn
+  integer(int64) nnq
+  integer(int64) nnr
+  integer(int64) nnw
+  integer(int64) np
+  integer(int64) npts(40)
+  integer(int64) nq
+  integer(int64) nqwmax
+  integer(int64) nw
   real ( kind = 8 ) rmax
   real ( kind = 8 ) rq
   real ( kind = 8 ) rs
@@ -609,10 +610,11 @@ function qs3val ( px, py, pz, n, x, y, z, f, nr, lcell, lnext, xyzmin, &
 !    unless N, NR, XYZDEL, or RMAX is invalid, in which case the 
 !    value 0 is returned.
 !
+  use iso_fortran_env
   implicit none
 !
-  integer n
-  integer nr
+  integer(int64) n
+  integer(int64) nr
 !
   real ( kind = 8 ) a(9,n)
   real ( kind = 8 ) delx
@@ -626,19 +628,19 @@ function qs3val ( px, py, pz, n, x, y, z, f, nr, lcell, lnext, xyzmin, &
   real ( kind = 8 ) dy
   real ( kind = 8 ) dz
   real ( kind = 8 ) f(n)
-  integer i
-  integer imax
-  integer imin
-  integer j
-  integer jmax
-  integer jmin
-  integer k
-  integer kmax
-  integer kmin
-  integer l
-  integer lcell(nr,nr,nr)
-  integer lnext(n)
-  integer lp
+  integer(int64) i
+  integer(int64) imax
+  integer(int64) imin
+  integer(int64) j
+  integer(int64) jmax
+  integer(int64) jmin
+  integer(int64) k
+  integer(int64) kmax
+  integer(int64) kmin
+  integer(int64) l
+  integer(int64) lcell(nr,nr,nr)
+  integer(int64) lnext(n)
+  integer(int64) lp
   real ( kind = 8 ) px
   real ( kind = 8 ) py
   real ( kind = 8 ) pz
@@ -694,22 +696,22 @@ function qs3val ( px, py, pz, n, x, y, z, f, nr, lcell, lnext, xyzmin, &
 !  intersected by (or contained in) a sphere of radius rmax
 !  centered at P.
 !
-  imin = int((xp-xmin-rmax)/dx) + 1
+  imin = int((xp-xmin-rmax)/dx, int64) + 1
   imin = max ( imin, 1 )
 
-  imax = int((xp-xmin+rmax)/dx) + 1
+  imax = int((xp-xmin+rmax)/dx, int64) + 1
   imax = min ( imax, nr )
 
-  jmin = int((yp-ymin-rmax)/dy) + 1
+  jmin = int((yp-ymin-rmax)/dy, int64) + 1
   jmin = max ( jmin, 1 )
 
-  jmax = int((yp-ymin+rmax)/dy) + 1
+  jmax = int((yp-ymin+rmax)/dy, int64) + 1
   jmax = min ( jmax, nr )
 
-  kmin = int((zp-zmin-rmax)/dz) + 1
+  kmin = int((zp-zmin-rmax)/dz, int64) + 1
   kmin = max ( kmin, 1 )
 
-  kmax = int((zp-zmin+rmax)/dz) + 1
+  kmax = int((zp-zmin+rmax)/dz, int64) + 1
   kmax = min ( kmax, nr )
 !
 !  Test for no cells within the sphere of radius RMAX.
@@ -862,10 +864,11 @@ subroutine qs3grd ( px, py, pz, n, x, y, z, f, nr, lcell, lnext, xyzmin, &
 !    2, if no errors were encountered but (PX.PY.PZ) is not within the 
 !       radius R(K) for any node K (and thus Q = QX = QY = QZ = 0).
 !
+  use iso_fortran_env
   implicit none
 !
-  integer n
-  integer nr
+  integer(int64) n
+  integer(int64) nr
 !
   real ( kind = 8 ) a(9,n)
   real ( kind = 8 ) delx
@@ -879,20 +882,20 @@ subroutine qs3grd ( px, py, pz, n, x, y, z, f, nr, lcell, lnext, xyzmin, &
   real ( kind = 8 ) dz
   real ( kind = 8 ) dzsq
   real ( kind = 8 ) f(n)
-  integer i
-  integer ier
-  integer imax
-  integer imin
-  integer j
-  integer jmax
-  integer jmin
-  integer k
-  integer kmax
-  integer kmin
-  integer l
-  integer lcell(nr,nr,nr)
-  integer lnext(n)
-  integer lp
+  integer(int64) i
+  integer(int64) ier
+  integer(int64) imax
+  integer(int64) imin
+  integer(int64) j
+  integer(int64) jmax
+  integer(int64) jmin
+  integer(int64) k
+  integer(int64) kmax
+  integer(int64) kmin
+  integer(int64) l
+  integer(int64) lcell(nr,nr,nr)
+  integer(int64) lnext(n)
+  integer(int64) lp
   real ( kind = 8 ) px
   real ( kind = 8 ) py
   real ( kind = 8 ) pz
@@ -961,22 +964,22 @@ subroutine qs3grd ( px, py, pz, n, x, y, z, f, nr, lcell, lnext, xyzmin, &
 !  intersected by (or contained in) a sphere of radius RMAX
 !  centered at P.
 !
-  imin = int((xp-xmin-rmax)/dx) + 1
+  imin = int((xp-xmin-rmax)/dx, int64) + 1
   imin = max ( imin, 1 )
 
-  imax = int((xp-xmin+rmax)/dx) + 1
+  imax = int((xp-xmin+rmax)/dx, int64) + 1
   imax = min ( imax, nr )
 
-  jmin = int((yp-ymin-rmax)/dy) + 1
+  jmin = int((yp-ymin-rmax)/dy, int64) + 1
   jmin = max ( jmin, 1 )
 
-  jmax = int((yp-ymin+rmax)/dy) + 1
+  jmax = int((yp-ymin+rmax)/dy, int64) + 1
   jmax = min ( jmax, nr )
 
-  kmin = int((zp-zmin-rmax)/dz) + 1
+  kmin = int((zp-zmin-rmax)/dz, int64) + 1
   kmin = max ( kmin, 1 )
 
-  kmax = int((zp-zmin+rmax)/dz) + 1
+  kmax = int((zp-zmin+rmax)/dz, int64) + 1
   kmax = min ( kmax, nr )
 !
 !  Test for no cells within the sphere of radius RMAX.
@@ -1176,9 +1179,10 @@ subroutine getnp3 ( px, py, pz, x, y, z, nr, lcell, lnext, xyzmin, &
 !    Output, real ( kind = 8 ) DSQ, squared euclidean distance between 
 !    P and node NP, or 0 if NP = 0.
 !
+  use iso_fortran_env
   implicit none
 !
-  integer nr
+  integer(int64) nr
 !
   real ( kind = 8 ) delx
   real ( kind = 8 ) dely
@@ -1188,30 +1192,30 @@ subroutine getnp3 ( px, py, pz, x, y, z, nr, lcell, lnext, xyzmin, &
   real ( kind = 8 ) dy
   real ( kind = 8 ) dz
   logical first
-  integer i
-  integer i0
-  integer i1
-  integer i2
-  integer imax
-  integer imin
-  integer j
-  integer j0
-  integer j1
-  integer j2
-  integer jmax
-  integer jmin
-  integer k
-  integer k0
-  integer k1
-  integer k2
-  integer kmax
-  integer kmin
-  integer l
-  integer lcell(nr,nr,nr)
-  integer lmin
-  integer ln
-  integer lnext(*)
-  integer np
+  integer(int64) i
+  integer(int64) i0
+  integer(int64) i1
+  integer(int64) i2
+  integer(int64) imax
+  integer(int64) imin
+  integer(int64) j
+  integer(int64) j0
+  integer(int64) j1
+  integer(int64) j2
+  integer(int64) jmax
+  integer(int64) jmin
+  integer(int64) k
+  integer(int64) k0
+  integer(int64) k1
+  integer(int64) k2
+  integer(int64) kmax
+  integer(int64) kmin
+  integer(int64) l
+  integer(int64) lcell(nr,nr,nr)
+  integer(int64) lmin
+  integer(int64) ln
+  integer(int64) lnext(*)
+  integer(int64) np
   real ( kind = 8 ) px
   real ( kind = 8 ) py
   real ( kind = 8 ) pz
@@ -1262,19 +1266,19 @@ subroutine getnp3 ( px, py, pz, x, y, z, nr, lcell, lnext, xyzmin, &
   delx = xp - xyzmin(1)
   dely = yp - xyzmin(2)
   delz = zp - xyzmin(3)
-  i0 = int(delx/dx) + 1
+  i0 = int(delx/dx, int64) + 1
   if ( i0 < 1 ) i0 = 1
   if ( nr < i0 ) then
     i0 = nr
   end if
 
-  j0 = int ( dely / dy ) + 1
+  j0 = int ( dely / dy, int64 ) + 1
   if ( j0 < 1 ) j0 = 1
   if ( nr < j0 ) then
     j0 = nr
   end if
 
-  k0 = int(delz/dz) + 1
+  k0 = int(delz/dz, int64) + 1
   if ( k0 < 1 ) k0 = 1
   if ( nr < k0 ) then
     k0 = nr
@@ -1340,17 +1344,17 @@ subroutine getnp3 ( px, py, pz, x, y, z, nr, lcell, lnext, xyzmin, &
   lmin = l
   rsmin = rsq
   r = sqrt(rsmin)
-  imin = int((delx-r)/dx) + 1
+  imin = int((delx-r)/dx, int64) + 1
   if ( imin < 1 ) imin = 1
-  imax = int((delx+r)/dx) + 1
+  imax = int((delx+r)/dx, int64) + 1
   if ( nr < imax ) imax = nr
-  jmin = int((dely-r)/dy) + 1
+  jmin = int((dely-r)/dy, int64) + 1
   if ( jmin < 1 ) jmin = 1
-  jmax = int((dely+r)/dy) + 1
+  jmax = int((dely+r)/dy, int64) + 1
   if ( nr < jmax ) jmax = nr
-  kmin = int((delz-r)/dz) + 1
+  kmin = int((delz-r)/dz, int64) + 1
   if ( kmin < 1 ) kmin = 1
-  kmax = int((delz+r)/dz) + 1
+  kmax = int((delz+r)/dz, int64) + 1
   if ( nr < kmax ) kmax = nr
   first = .false.
   go to 4
@@ -1614,6 +1618,7 @@ subroutine setup3 ( xk, yk, zk, fk, xi, yi, zi, fi, s1, s2, r, row )
 !    w1 =   w/s1
 !    w2 =   w/s2
 !
+  use iso_fortran_env
   implicit none
 !
   real ( kind = 8 ) d
@@ -1745,26 +1750,27 @@ subroutine store3 ( n, x, y, z, nr, lcell, lnext, xyzmin, xyzdel, ier )
 !    1, if n < 2 or nr < 1.
 !    2, if a component of xyzdel is not positive.
 !
+  use iso_fortran_env
   implicit none
 !
-  integer n
-  integer nr
+  integer(int64) n
+  integer(int64) nr
 !
   real ( kind = 8 ) delx
   real ( kind = 8 ) dely
   real ( kind = 8 ) delz
-  integer i
-  integer ier
-  integer j
-  integer k
-  integer l
-  integer lb
-  integer lcell(nr,nr,nr)
-  integer ll
-  integer lnext(n)
-  integer nn
-  integer nnr
-  integer np1
+  integer(int64) i
+  integer(int64) ier
+  integer(int64) j
+  integer(int64) k
+  integer(int64) l
+  integer(int64) lb
+  integer(int64) lcell(nr,nr,nr)
+  integer(int64) ll
+  integer(int64) lnext(n)
+  integer(int64) nn
+  integer(int64) nnr
+  integer(int64) np1
   real ( kind = 8 ) x(n)
   real ( kind = 8 ) xmn
   real ( kind = 8 ) xmx
@@ -1824,11 +1830,11 @@ subroutine store3 ( n, x, y, z, nr, lcell, lnext, xyzmin, xyzdel, ier )
 
   do ll = 1, nn
     lb = np1 - ll
-    i = int((x(lb)-xmn)/delx) + 1
+    i = int((x(lb)-xmn)/delx, int64) + 1
     if ( nnr < i ) i = nnr
-    j = int((y(lb)-ymn)/dely) + 1
+    j = int((y(lb)-ymn)/dely, int64) + 1
     if ( nnr < j ) j = nnr
-    k = int((z(lb)-zmn)/delz) + 1
+    k = int((z(lb)-zmn)/delz, int64) + 1
     if ( nnr < k ) k = nnr
 
     l = lcell(i,j,k)
@@ -1867,23 +1873,24 @@ subroutine timestamp ( )
 !
 !    None
 !
+  use iso_fortran_env
   implicit none
 !
   character ( len = 8 ) ampm
-  integer d
+  integer(int64) d
   character ( len = 8 ) date
-  integer h
-  integer m
-  integer mm
+  integer(int64) h
+  integer(int64) m
+  integer(int64) mm
   character ( len = 9 ), parameter, dimension(12) :: month = (/ &
     'January  ', 'February ', 'March    ', 'April    ', &
     'May      ', 'June     ', 'July     ', 'August   ', &
     'September', 'October  ', 'November ', 'December ' /)
-  integer n
-  integer s
+  integer(int64) n
+  integer(int64) s
   character ( len = 10 )  time
-  integer values(8)
-  integer y
+  integer(int64) values(8)
+  integer(int64) y
   character ( len = 5 ) zone
 !
   call date_and_time ( date, time, zone, values )
