@@ -23,6 +23,14 @@
 
 #include <cl_global.h>
 
+inline double2 complex_number(const double x, const double y){
+#ifdef CUDA
+  return double2(x, y);
+#else
+    return (double2) (x, y);
+#endif
+}
+
 inline double2 complex_conj(const double2 a){
 #ifdef CUDA
   return double2(a.x, -a.y);
