@@ -28,7 +28,7 @@
 #define restrict __restrict__
 #define barrier(x) __syncthreads()
 
-__device__ __forceinline__ static int get_global_id(const int ii){
+__device__ __forceinline__ static size_t get_global_id(const int ii){
   switch(ii){
   case 0 :
     return threadIdx.x + blockDim.x*blockIdx.x;
@@ -40,7 +40,7 @@ __device__ __forceinline__ static int get_global_id(const int ii){
   return 0;
 }
 
-__device__ __forceinline__ static int get_global_size(const int ii){
+__device__ __forceinline__ static size_t get_global_size(const int ii){
   switch(ii){
   case 0 :
     return blockDim.x*gridDim.x;
@@ -52,7 +52,7 @@ __device__ __forceinline__ static int get_global_size(const int ii){
   return 0;
 }
 
-__device__ __forceinline__ static int get_local_id(const int ii){
+__device__ __forceinline__ static size_t get_local_id(const int ii){
   switch(ii){
   case 0 :
     return threadIdx.x;
@@ -64,7 +64,7 @@ __device__ __forceinline__ static int get_local_id(const int ii){
   return 0;
 }
 
-__device__ __forceinline__ static int get_local_size(const int ii){
+__device__ __forceinline__ static size_t get_local_size(const int ii){
   switch(ii){
   case 0 :
     return blockDim.x;
