@@ -74,6 +74,10 @@ typedef int CUstream;
       cuGetErrorName(result, &msg);                               \
       std::cerr << "\nerror: " #x " failed with error "           \
                 << msg << '\n';                                   \
+      if (result == CUDA_ERROR_OUT_OF_MEMORY) {                   \
+        std::cerr << "Octopus could not allocate enough memory on the GPU.\n"; \
+        std::cerr << "Please use either more GPUs to distribute the memory or try StatesPack = no to keep the states mostly on the CPU.\n"; \
+      }                                                           \
       exit(1);                                                    \
     }                                                             \
   } while(0)
@@ -453,7 +457,9 @@ extern "C" void FC_FUNC_(cuda_device_get_warpsize, CUDA_DEVICE_GET_WARPSIZE)(CUd
 }
 
 extern "C" void FC_FUNC_(cuda_deref, CUDA_DEREF)(CUdeviceptr ** cuda_ptr, void ** cuda_deref_ptr) {
+#ifdef HAVE_CUDA
   *cuda_deref_ptr = (void *) **cuda_ptr;
+#endif
 }
 
 extern "C" void FC_FUNC_(cuda_set_stream, CUDA_SET_STREAM)(CUstream ** stream, fint * number) {
