@@ -24,6 +24,8 @@ The functions in this file write and read an array to binary file.
 
 */
 
+#define _FILE_OFFSET_BITS  64
+
 #include <config.h>
 #include <math.h>
 #include <string.h>
@@ -69,9 +71,9 @@ typedef unsigned long uint64_t;
 
 typedef char byte;
 
-static const int size_of[6]      = {4, 8, 8, 16, 4, 8};
-static const int base_size_of[6] = {4, 8, 4, 8, 4, 8};
-static const int is_integer[6]   = {0, 0, 0, 0, 1, 1};
+static const int64_t size_of[6]      = {4, 8, 8, 16, 4, 8};
+static const int64_t base_size_of[6] = {4, 8, 4, 8, 4, 8};
+static const int64_t is_integer[6]   = {0, 0, 0, 0, 1, 1};
 
 static inline void inf_error(const char * msg){
 #ifdef HAVE_PERROR
@@ -183,7 +185,7 @@ static inline int check_header(header_t * hp, int * correct_endianness){
   return 0;
 }
 
-void io_write_header(const int * np, int * type, int * ierr, int * iio, char * fname)
+void io_write_header(const int64_t * np, int * type, int * ierr, int * iio, char * fname)
 {
   header_t * hp;
   int fd;
@@ -224,10 +226,13 @@ void io_write_header(const int * np, int * type, int * ierr, int * iio, char * f
   *iio += 1;
 }
 
-void write_binary(const int * np, void * ff, int * type, int * ierr, int * iio, int * nhd, int * flpe, char * fname)
+void write_binary(const int64_t * np, void * ff, int * type, int * ierr, int * iio, int * nhd, int * flpe, char * fname)
 {
-  int fd, ii;
+  int fd;
+  int64_t ii;
   ssize_t moved;
+  ssize_t bytes_to_write;
+  ssize_t offset;
 
   assert(np > 0);
   *ierr = 0;
@@ -255,12 +260,18 @@ void write_binary(const int * np, void * ff, int * type, int * ierr, int * iio,
   }
   
   /* now write the values */
-  moved = write(fd, ff, (*np)*size_of[(*type)]);
-
-  if(moved < (*np)*size_of[(*type)]){
-    /* we couldn't write the whole dataset */
-    inf_error("octopus.write_binary in actual writing");
-    *ierr = 3;
+  bytes_to_write = (*np)*size_of[(*type)];
+  offset = 0;
+  while (bytes_to_write > 0) {
+    moved = write(fd, ff + offset, bytes_to_write);
+    if(moved < 0){
+      /* an error occurred */
+      inf_error("octopus.write_binary in actual writing");
+      *ierr = 3;
+      break;
+    }
+    bytes_to_write -= moved;
+    offset += moved;
   }
 
   /* close the file */
@@ -302,10 +313,11 @@ void io_read_header(header_t * hp, int * correct_endianness, int * ierr, int * i
   (*iio)++;
 }
 
-void read_binary(const int * np, const int * offset, byte * ff, int * output_type, int * ierr, int * iio, char * fname)
+void read_binary(const int64_t * np, const int64_t * offset, byte * ff, int * output_type, int * ierr, int * iio, char * fname)
 {
   header_t * hp;
-  int fd, ii;
+  int fd;
+  int64_t ii;
   ssize_t moved;
   int correct_endianness;
   byte * read_f;
@@ -474,7 +486,7 @@ static void convert ( multi * in, multi * out, int t_in, int t_out){
 }
 
 
-void get_info_binary(int * np, int * type, int * file_size, int * ierr, int * iio, char * fname)
+void get_info_binary(int64_t * np, int * type, int64_t * file_size, int * ierr, int * iio, char * fname)
 {
   header_t * hp;
   int correct_endianness;
@@ -496,5 +508,5 @@ void get_info_binary(int * np, int * type, int * file_size, int * ierr, int * ii
   free(hp);
 
   stat(fname, &st);
-  *file_size = (int) st.st_size;
+  *file_size = (int64_t) st.st_size;
 }
