@@ -461,18 +461,6 @@ void FC_FUNC_(oct_search_file_lr, OCT_SEARCH_FILE_LR)
 
 }
 
-double FC_FUNC_(oct_hypotd, OCT_HYPOTD)
-  (double *x, double *y)
-{
-  return hypot(*x, *y);
-}
-
-float FC_FUNC_(oct_hypotf, OCT_HYPOTF)
-  (float *x, float *y)
-{
-  return hypotf(*x, *y);
-}
-
 void * FC_FUNC_(oct_get_memory_usage, OCT_GET_MEMORY_USAGE)()
 {
 #if defined(HAVE_SYSCONF) && defined(HAVE_GETPID)
