@@ -1,5 +1,6 @@
 /*
  Copyright (C) 2010 X. Andrade
+ Copyright (C) 2021 S. Ohlmann
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -19,21 +20,20 @@
 */
 
 #include <config.h>
-typedef long long checksum_t;
+#include <fortran_types.h>
 
 /* This function implements a very stupid checksum function. The only
    important thing is that it produces different results for arrays
    with the same numbers but in different orders. For more serious
    applications a better function must be used. */
 
-void FC_FUNC_(checksum_calculate, CHECKSUM_CALCULATE)(const int * algorithm, const int * narray, const unsigned int * array, checksum_t * sum){
-  int i;
-  checksum_t mult;
+void FC_FUNC_(checksum_calculate, CHECKSUM_CALCULATE)(const fint * algorithm, const fint8 * narray, const fint8 * array, fint8 * sum){
+  fint8 i;
+  fint8 mult;
   *sum = 0;
   mult = 1;
   for(i = 0; i < *narray; i++){
     *sum += mult*array[i];
     mult++;
   }
-  *sum %= (1<<31);
 }
